@@ -1,10 +1,13 @@
+"""
+Unit test for DotProductComp.
+"""
 from __future__ import print_function, division, absolute_import
 
 import unittest
 
 import numpy as np
 
-from openmdao.api import Problem, Group, IndepVarComp, DotProductComp
+import openmdao.api as om
 
 
 class TestDotProductCompNx3(unittest.TestCase):
@@ -12,9 +15,9 @@ class TestDotProductCompNx3(unittest.TestCase):
     def setUp(self):
         self.nn = 5
 
-        self.p = Problem(model=Group())
+        self.p = om.Problem()
 
-        ivc = IndepVarComp()
+        ivc = om.IndepVarComp()
         ivc.add_output(name='a', shape=(self.nn, 3))
         ivc.add_output(name='b', shape=(self.nn, 3))
 
@@ -23,7 +26,7 @@ class TestDotProductCompNx3(unittest.TestCase):
                                    promotes_outputs=['a', 'b'])
 
         self.p.model.add_subsystem(name='dot_prod_comp',
-                                   subsys=DotProductComp(vec_size=self.nn))
+                                   subsys=om.DotProductComp(vec_size=self.nn))
 
         self.p.model.connect('a', 'dot_prod_comp.a')
         self.p.model.connect('b', 'dot_prod_comp.b')
@@ -60,9 +63,9 @@ class TestDotProductCompNx4(unittest.TestCase):
     def setUp(self):
         self.nn = 100
 
-        self.p = Problem(model=Group())
+        self.p = om.Problem()
 
-        ivc = IndepVarComp()
+        ivc = om.IndepVarComp()
         ivc.add_output(name='a', shape=(self.nn, 4))
         ivc.add_output(name='b', shape=(self.nn, 4))
 
@@ -71,7 +74,7 @@ class TestDotProductCompNx4(unittest.TestCase):
                                    promotes_outputs=['a', 'b'])
 
         self.p.model.add_subsystem(name='dot_prod_comp',
-                                   subsys=DotProductComp(vec_size=self.nn, length=4))
+                                   subsys=om.DotProductComp(vec_size=self.nn, length=4))
 
         self.p.model.connect('a', 'dot_prod_comp.a')
         self.p.model.connect('b', 'dot_prod_comp.b')
@@ -108,9 +111,9 @@ class TestUnits(unittest.TestCase):
     def setUp(self):
         self.nn = 5
 
-        self.p = Problem(model=Group())
+        self.p = om.Problem()
 
-        ivc = IndepVarComp()
+        ivc = om.IndepVarComp()
         ivc.add_output(name='a', shape=(self.nn, 3), units='lbf')
         ivc.add_output(name='b', shape=(self.nn, 3), units='ft/s')
 
@@ -119,9 +122,9 @@ class TestUnits(unittest.TestCase):
                                    promotes_outputs=['a', 'b'])
 
         self.p.model.add_subsystem(name='dot_prod_comp',
-                                   subsys=DotProductComp(vec_size=self.nn,
-                                                         a_units='N', b_units='m/s',
-                                                         c_units='W'))
+                                   subsys=om.DotProductComp(vec_size=self.nn,
+                                                            a_units='N', b_units='m/s',
+                                                            c_units='W'))
 
         self.p.model.connect('a', 'dot_prod_comp.a')
         self.p.model.connect('b', 'dot_prod_comp.b')
@@ -154,7 +157,7 @@ class TestUnits(unittest.TestCase):
                                                decimal=6)
 
 
-class TestForDocs(unittest.TestCase):
+class TestFeature(unittest.TestCase):
 
     def test(self):
         """
@@ -162,14 +165,15 @@ class TestForDocs(unittest.TestCase):
         at 100 points simultaneously.
         """
         import numpy as np
-        from openmdao.api import Problem, Group, IndepVarComp, DotProductComp
+
+        import openmdao.api as om
         from openmdao.utils.assert_utils import assert_rel_error
 
         n = 100
 
-        p = Problem(model=Group())
+        p = om.Problem()
 
-        ivc = IndepVarComp()
+        ivc = om.IndepVarComp()
         ivc.add_output(name='force', shape=(n, 3))
         ivc.add_output(name='vel', shape=(n, 3))
 
@@ -177,8 +181,8 @@ class TestForDocs(unittest.TestCase):
                               subsys=ivc,
                               promotes_outputs=['force', 'vel'])
 
-        dp_comp = DotProductComp(vec_size=n, length=3, a_name='F', b_name='v', c_name='P',
-                                 a_units='N', b_units='m/s', c_units='W')
+        dp_comp = om.DotProductComp(vec_size=n, length=3, a_name='F', b_name='v', c_name='P',
+                                    a_units='N', b_units='m/s', c_units='W')
 
         p.model.add_subsystem(name='dot_prod_comp', subsys=dp_comp)
 
