@@ -2,7 +2,11 @@
 
 from __future__ import division
 
-from collections import OrderedDict, Iterable, Counter, defaultdict
+from collections import OrderedDict, Counter, defaultdict
+try:
+    from collections.abc import Iterable
+except ImportError:
+    from collections import Iterable
 from itertools import product
 from six import string_types, iteritems, itervalues
 
@@ -19,24 +23,29 @@ from openmdao.utils.units import valid_units
 from openmdao.utils.name_maps import rel_key2abs_key, abs_key2rel_key, rel_name2abs_name
 from openmdao.utils.mpi import MPI
 from openmdao.utils.general_utils import format_as_float_or_array, ensure_compatible, \
-    warn_deprecation, find_matches, simple_warning
+    warn_deprecation, find_matches, simple_warning, make_set
 import openmdao.utils.coloring as coloring_mod
 
 
 # the following metadata will be accessible for vars on all procs
 global_meta_names = {
-    'input': ('units', 'shape', 'size', 'distributed'),
+    'input': ('units', 'shape', 'size', 'distributed', 'tags'),
     'output': ('units', 'shape', 'size',
-               'ref', 'ref0', 'res_ref', 'distributed', 'lower', 'upper'),
+               'ref', 'ref0', 'res_ref', 'distributed', 'lower', 'upper', 'tags'),
 }
 
 _full_slice = slice(None)
+_forbidden_chars = ['.', '*', '?', '!', '[', ']']
+_whitespace = set([' ', '\t', '\r', '\n'])
 
 
 def _valid_var_name(name):
     """
     Determine if the proposed name is a valid variable name.
 
+    Leading and trailing whitespace is illegal, and a specific list of characters
+    are illegal anywhere in the string.
+
     Parameters
     ----------
     name : str
@@ -47,9 +56,13 @@ def _valid_var_name(name):
     bool
         True if the proposed name is a valid variable name, else False.
     """
-    forbidden_chars = ['.', '*', '?', '!', '[', ']']
-
-    return not any([True for character in forbidden_chars if character in name])
+    global _forbidden_chars, _whitespace
+    if not name:
+        return False
+    for char in _forbidden_chars:
+        if char in name:
+            return False
+    return name[0] not in _whitespace and name[-1] not in _whitespace
 
 
 class Component(System):
@@ -169,13 +182,16 @@ class Component(System):
         self.pathname = pathname
         self._problem_options = prob_options
 
+        self.options._parent_name = self.msginfo
+        self.recording_options._parent_name = self.msginfo
+
         orig_comm = comm
         if self._num_par_fd > 1:
             if comm.size > 1:
                 comm = self._setup_par_fd_procs(comm)
             elif not MPI:
-                msg = ("'%s': MPI is not active but num_par_fd = %d. No parallel finite difference "
-                       "will be performed." % (self.pathname, self._num_par_fd))
+                msg = ("%s: MPI is not active but num_par_fd = %d. No parallel finite difference "
+                       "will be performed." % (self.msginfo, self._num_par_fd))
                 simple_warning(msg)
 
         self.comm = comm
@@ -204,7 +220,7 @@ class Component(System):
         # used by the system setup).
         if self._num_par_fd > 1 and orig_comm.size > 1 and not (self._owns_approx_jac or
                                                                 self._approx_schemes):
-            raise RuntimeError("'%s': num_par_fd is > 1 but no FD is active." % self.pathname)
+            raise RuntimeError("%s: num_par_fd is > 1 but no FD is active." % self.msginfo)
 
         # check here if declare_coloring was called during setup but declare_partials
         # wasn't.  If declare partials wasn't called, call it with of='*' and wrt='*' so we'll
@@ -217,7 +233,7 @@ class Component(System):
                 method = self._coloring_info['method']
                 simple_warning("%s: declare_coloring or use_fixed_coloring was called but no approx"
                                " partials were declared.  Declaring all partials as approximated "
-                               "using default metadata and method='%s'." % (self.pathname, method))
+                               "using default metadata and method='%s'." % (self.msginfo, method))
                 self.declare_partials('*', '*', method=method)
 
         self._static_mode = True
@@ -245,9 +261,14 @@ class Component(System):
         """
         global global_meta_names
         super(Component, self)._setup_var_data()
+
         allprocs_abs_names = self._var_allprocs_abs_names
+        allprocs_abs_names_discrete = self._var_allprocs_abs_names_discrete
+
         allprocs_prom2abs_list = self._var_allprocs_prom2abs_list
+
         abs2prom = self._var_abs2prom
+
         allprocs_abs2meta = self._var_allprocs_abs2meta
         abs2meta = self._var_abs2meta
 
@@ -259,7 +280,7 @@ class Component(System):
                 abs_name = prefix + prom_name
                 metadata = self._var_rel2meta[prom_name]
 
-                # Compute allprocs_abs_names, abs_names
+                # Compute allprocs_abs_names
                 allprocs_abs_names[type_].append(abs_name)
 
                 # Compute allprocs_prom2abs_list, abs2prom
@@ -277,12 +298,22 @@ class Component(System):
 
             for prom_name, val in iteritems(self._var_discrete[type_]):
                 abs_name = prefix + prom_name
+
+                # Compute allprocs_abs_names_discrete
+                allprocs_abs_names_discrete[type_].append(abs_name)
+
+                # Compute allprocs_prom2abs_list, abs2prom
                 allprocs_prom2abs_list[type_][prom_name] = [abs_name]
+                abs2prom[type_][abs_name] = prom_name
+
+                # Compute allprocs_discrete (metadata for discrete vars)
                 self._var_allprocs_discrete[type_][abs_name] = val
 
-        self._var_allprocs_abs2prom = self._var_abs2prom
+        self._var_allprocs_abs2prom = abs2prom
+
+        self._var_abs_names = allprocs_abs_names
+        self._var_abs_names_discrete = allprocs_abs_names_discrete
 
-        self._var_abs_names = self._var_allprocs_abs_names
         if self._var_discrete['input'] or self._var_discrete['output']:
             self._discrete_inputs = _DictValues(self._var_discrete['input'])
             self._discrete_outputs = _DictValues(self._var_discrete['output'])
@@ -345,6 +376,9 @@ class Component(System):
         if self._use_derivatives:
             self._var_sizes['nonlinear'] = self._var_sizes['linear']
 
+        # for a component, all vars are 'owned'
+        self._owned_sizes = self._var_sizes['nonlinear']['output']
+
         self._setup_global_shapes()
 
     def _setup_partials(self, recurse=True):
@@ -363,11 +397,15 @@ class Component(System):
             of, wrt = key
             self._declare_partials(of, wrt, dct)
 
-    def _update_wrt_matches(self):
+    def _update_wrt_matches(self, info):
         """
         Determine the list of wrt variables that match the wildcard(s) given in declare_coloring.
+
+        Parameters
+        ----------
+        info : dict
+            Coloring metadata dict.
         """
-        info = self._coloring_info
         ofs, allwrt = self._get_partials_varlists()
         wrt_patterns = info['wrt_patterns']
         matches_prom = set()
@@ -376,8 +414,8 @@ class Component(System):
 
         # error if nothing matched
         if not matches_prom:
-            raise ValueError("Invalid 'wrt' variable(s) specified for colored approx partial "
-                             "options on Component '{}': {}.".format(self.pathname, wrt_patterns))
+            raise ValueError("{}: Invalid 'wrt' variable(s) specified for colored approx partial "
+                             "options: {}.".format(self.msginfo, wrt_patterns))
 
         info['wrt_matches_prom'] = matches_prom
         info['wrt_matches'] = [rel_name2abs_name(self, n) for n in matches_prom]
@@ -408,7 +446,7 @@ class Component(System):
                     self._subjacs_info[abs_key]['sparsity'] = tup
 
     def add_input(self, name, val=1.0, shape=None, src_indices=None, flat_src_indices=None,
-                  units=None, desc=''):
+                  units=None, desc='', tags=None):
         """
         Add an input variable to the component.
 
@@ -436,6 +474,9 @@ class Component(System):
             during execution. Default is None, which means it is unitless.
         desc : str
             description of the variable
+        tags : str or list of strs
+            User defined tags that can be used to filter what gets listed when calling
+            list_inputs and list_outputs.
 
         Returns
         -------
@@ -453,26 +494,28 @@ class Component(System):
 
         # First, type check all arguments
         if not isinstance(name, str):
-            raise TypeError('The name argument should be a string.')
-        if not name:
-            raise NameError('The name argument should be a non-empty string.')
+            raise TypeError('%s: The name argument should be a string.' % self.msginfo)
         if not _valid_var_name(name):
-            raise NameError("'%s' is not a valid input name." % name)
+            raise NameError("%s: '%s' is not a valid input name." % (self.msginfo, name))
         if not isscalar(val) and not isinstance(val, (list, tuple, ndarray, Iterable)):
-            raise TypeError('The val argument should be a float, list, tuple, ndarray or Iterable')
+            raise TypeError('%s: The val argument should be a float, list, tuple, ndarray or '
+                            'Iterable' % self.msginfo)
         if shape is not None and not isinstance(shape, (int, tuple, list, np.integer)):
-            raise TypeError("The shape argument should be an int, tuple, or list but "
-                            "a '%s' was given" % type(shape))
+            raise TypeError("%s: The shape argument should be an int, tuple, or list but "
+                            "a '%s' was given" % (self.msginfo, type(shape)))
         if src_indices is not None and not isinstance(src_indices, (int, list, tuple,
                                                                     ndarray, Iterable)):
-            raise TypeError('The src_indices argument should be an int, list, '
-                            'tuple, ndarray or Iterable')
+            raise TypeError('%s: The src_indices argument should be an int, list, '
+                            'tuple, ndarray or Iterable' % self.msginfo)
         if units is not None and not isinstance(units, str):
-            raise TypeError('The units argument should be a str or None')
+            raise TypeError('%s: The units argument should be a str or None' % self.msginfo)
 
         # Check that units are valid
         if units is not None and not valid_units(units):
-            raise ValueError("The units '%s' are invalid" % units)
+            raise ValueError("%s: The units '%s' are invalid" % (self.msginfo, units))
+
+        if tags is not None and not isinstance(tags, (str, list)):
+            raise TypeError('The tags argument should be a str or list')
 
         metadata = {}
 
@@ -492,6 +535,8 @@ class Component(System):
         metadata['desc'] = desc
         metadata['distributed'] = self.options['distributed']
 
+        metadata['tags'] = make_set(tags)
+
         # We may not know the pathname yet, so we have to use name for now, instead of abs_name.
         if self._static_mode:
             var_rel2meta = self._static_var_rel2meta
@@ -502,15 +547,14 @@ class Component(System):
 
         # Disallow dupes
         if name in var_rel2meta:
-            msg = "Variable name '{}' already exists.".format(name)
-            raise ValueError(msg)
+            raise ValueError("{}: Variable name '{}' already exists.".format(self.msginfo, name))
 
         var_rel2meta[name] = metadata
         var_rel_names['input'].append(name)
 
         return metadata
 
-    def add_discrete_input(self, name, val, desc=''):
+    def add_discrete_input(self, name, val, desc='', tags=None):
         """
         Add a discrete input variable to the component.
 
@@ -522,6 +566,9 @@ class Component(System):
             The initial value of the variable being added.
         desc : str
             description of the variable
+        tags : str or list of strs
+            User defined tags that can be used to filter what gets listed when calling
+            list_inputs and list_outputs.
 
         Returns
         -------
@@ -530,16 +577,17 @@ class Component(System):
         """
         # First, type check all arguments
         if not isinstance(name, str):
-            raise TypeError('The name argument should be a string.')
-        if not name:
-            raise NameError('The name argument should be a non-empty string.')
+            raise TypeError('%s: The name argument should be a string.' % self.msginfo)
         if not _valid_var_name(name):
-            raise NameError("'%s' is not a valid input name." % name)
+            raise NameError("%s: '%s' is not a valid input name." % (self.msginfo, name))
+        if tags is not None and not isinstance(tags, (str, list)):
+            raise TypeError('%s: The tags argument should be a str or list' % self.msginfo)
 
         metadata = {
             'value': val,
             'type': type(val),
             'desc': desc,
+            'tags': make_set(tags),
         }
 
         if self._static_mode:
@@ -549,15 +597,14 @@ class Component(System):
 
         # Disallow dupes
         if name in var_rel2meta:
-            msg = "Variable name '{}' already exists.".format(name)
-            raise ValueError(msg)
+            raise ValueError("{}: Variable name '{}' already exists.".format(self.msginfo, name))
 
         var_rel2meta[name] = self._var_discrete['input'][name] = metadata
 
         return metadata
 
     def add_output(self, name, val=1.0, shape=None, units=None, res_units=None, desc='',
-                   lower=None, upper=None, ref=1.0, ref0=0.0, res_ref=1.0):
+                   lower=None, upper=None, ref=1.0, ref0=0.0, res_ref=1.0, tags=None):
         """
         Add an output variable to the component.
 
@@ -597,6 +644,9 @@ class Component(System):
         res_ref : float or ndarray
             Scaling parameter. The value in the user-defined res_units of this output's residual
             when the scaled value is 1. Default is 1.
+        tags : str or list of strs or set of strs
+            User defined tags that can be used to filter what gets listed when calling
+            list_inputs and list_outputs.
 
         Returns
         -------
@@ -613,34 +663,35 @@ class Component(System):
             units = None
 
         if not isinstance(name, str):
-            raise TypeError('The name argument should be a string.')
-        if not name:
-            raise NameError('The name argument should be a non-empty string.')
+            raise TypeError('%s: The name argument should be a string.' % self.msginfo)
         if not _valid_var_name(name):
-            raise NameError("'%s' is not a valid output name." % name)
+            raise NameError("%s: '%s' is not a valid output name." % (self.msginfo, name))
         if not isscalar(val) and not isinstance(val, (list, tuple, ndarray, Iterable)):
-            msg = 'The val argument should be a float, list, tuple, ndarray or Iterable'
-            raise TypeError(msg)
+            msg = '%s: The val argument should be a float, list, tuple, ndarray or Iterable'
+            raise TypeError(msg % self.msginfo)
         if not isscalar(ref) and not isinstance(val, (list, tuple, ndarray, Iterable)):
-            msg = 'The ref argument should be a float, list, tuple, ndarray or Iterable'
-            raise TypeError(msg)
+            msg = '%s: The ref argument should be a float, list, tuple, ndarray or Iterable'
+            raise TypeError(msg % self.msginfo)
         if not isscalar(ref0) and not isinstance(val, (list, tuple, ndarray, Iterable)):
-            msg = 'The ref0 argument should be a float, list, tuple, ndarray or Iterable'
-            raise TypeError(msg)
+            msg = '%s: The ref0 argument should be a float, list, tuple, ndarray or Iterable'
+            raise TypeError(msg % self.msginfo)
         if not isscalar(res_ref) and not isinstance(val, (list, tuple, ndarray, Iterable)):
-            msg = 'The res_ref argument should be a float, list, tuple, ndarray or Iterable'
-            raise TypeError(msg)
+            msg = '%s: The res_ref argument should be a float, list, tuple, ndarray or Iterable'
+            raise TypeError(msg % self.msginfo)
         if shape is not None and not isinstance(shape, (int, tuple, list, np.integer)):
-            raise TypeError("The shape argument should be an int, tuple, or list but "
-                            "a '%s' was given" % type(shape))
+            raise TypeError("%s: The shape argument should be an int, tuple, or list but "
+                            "a '%s' was given" % (self.msginfo, type(shape)))
         if units is not None and not isinstance(units, str):
-            raise TypeError('The units argument should be a str or None')
+            raise TypeError('%s: The units argument should be a str or None' % self.msginfo)
         if res_units is not None and not isinstance(res_units, str):
-            raise TypeError('The res_units argument should be a str or None')
+            raise TypeError('%s: The res_units argument should be a str or None' % self.msginfo)
 
         # Check that units are valid
         if units is not None and not valid_units(units):
-            raise ValueError("The units '%s' are invalid" % units)
+            raise ValueError("%s: The units '%s' are invalid" % (self.msginfo, units))
+
+        if tags is not None and not isinstance(tags, (str, set, list)):
+            raise TypeError('The tags argument should be a str, set, or list')
 
         metadata = {}
 
@@ -670,8 +721,8 @@ class Component(System):
             if not isscalar(item):
                 it = atleast_1d(item)
                 if it.shape != metadata['shape']:
-                    raise ValueError("'{}': When adding output '{}', expected shape {} but got "
-                                     "shape {} for argument '{}'.".format(self.name, name,
+                    raise ValueError("{}: When adding output '{}', expected shape {} but got "
+                                     "shape {} for argument '{}'.".format(self.msginfo, name,
                                                                           metadata['shape'],
                                                                           it.shape, item_name))
 
@@ -700,6 +751,8 @@ class Component(System):
 
         metadata['distributed'] = self.options['distributed']
 
+        metadata['tags'] = make_set(tags)
+
         # We may not know the pathname yet, so we have to use name for now, instead of abs_name.
         if self._static_mode:
             var_rel2meta = self._static_var_rel2meta
@@ -710,15 +763,14 @@ class Component(System):
 
         # Disallow dupes
         if name in var_rel2meta:
-            msg = "Variable name '{}' already exists.".format(name)
-            raise ValueError(msg)
+            raise ValueError("{}: Variable name '{}' already exists.".format(self.msginfo, name))
 
         var_rel2meta[name] = metadata
         var_rel_names['output'].append(name)
 
         return metadata
 
-    def add_discrete_output(self, name, val, desc=''):
+    def add_discrete_output(self, name, val, desc='', tags=None):
         """
         Add an output variable to the component.
 
@@ -730,6 +782,9 @@ class Component(System):
             The initial value of the variable being added.
         desc : str
             description of the variable.
+        tags : str or list of strs or set of strs
+            User defined tags that can be used to filter what gets listed when calling
+            list_inputs and list_outputs.
 
         Returns
         -------
@@ -737,16 +792,17 @@ class Component(System):
             metadata for added variable
         """
         if not isinstance(name, str):
-            raise TypeError('The name argument should be a string.')
-        if not name:
-            raise NameError('The name argument should be a non-empty string.')
+            raise TypeError('%s: The name argument should be a string.' % self.msginfo)
         if not _valid_var_name(name):
-            raise NameError("'%s' is not a valid output name." % name)
+            raise NameError("%s: '%s' is not a valid output name." % (self.msginfo, name))
+        if tags is not None and not isinstance(tags, (str, set, list)):
+            raise TypeError('%s: The tags argument should be a str, set, or list' % self.msginfo)
 
         metadata = {
             'value': val,
             'type': type(val),
-            'desc': desc
+            'desc': desc,
+            'tags': make_set(tags)
         }
 
         if self._static_mode:
@@ -756,8 +812,7 @@ class Component(System):
 
         # Disallow dupes
         if name in var_rel2meta:
-            msg = "Variable name '{}' already exists.".format(name)
-            raise ValueError(msg)
+            raise ValueError("{}: Variable name '{}' already exists.".format(self.msginfo, name))
 
         var_rel2meta[name] = self._var_discrete['output'][name] = metadata
 
@@ -789,9 +844,11 @@ class Component(System):
             of_pattern, of_matches = of_bundle
             wrt_pattern, wrt_matches = wrt_bundle
             if not of_matches:
-                raise ValueError('No matches were found for of="{}"'.format(of_pattern))
+                raise ValueError('{}: No matches were found for of="{}"'.format(self.msginfo,
+                                                                                of_pattern))
             if not wrt_matches:
-                raise ValueError('No matches were found for wrt="{}"'.format(wrt_pattern))
+                raise ValueError('{}: No matches were found for wrt="{}"'.format(self.msginfo,
+                                                                                 wrt_pattern))
 
             info = self._subjacs_info
             for rel_key in product(of_matches, wrt_matches):
@@ -854,8 +911,8 @@ class Component(System):
         try:
             method_func = _supported_methods[method]
         except KeyError:
-            msg = 'Method "{}" is not supported, method must be one of {}'
-            raise ValueError(msg.format(method, list(_supported_methods)))
+            msg = '{}: d({})/d({}): method "{}" is not supported, method must be one of {}'
+            raise ValueError(msg.format(self.msginfo, of, wrt, method, sorted(_supported_methods)))
 
         if isinstance(of, list):
             of = tuple(of)
@@ -867,7 +924,8 @@ class Component(System):
 
         # If only one of rows/cols is specified
         if (rows is None) ^ (cols is None):
-            raise ValueError('If one of rows/cols is specified, then both must be specified')
+            raise ValueError('{}: d({})/d({}): If one of rows/cols is specified, then '
+                             'both must be specified.'.format(self.msginfo, of, wrt))
 
         if dependent:
             meta['value'] = val
@@ -878,18 +936,19 @@ class Component(System):
                 # First, check the length of rows and cols to catch this easy mistake and give a
                 # clear message.
                 if len(cols) != len(rows):
-                    msg = "{0}: declare_partials has been called with rows and cols, which" + \
-                          " should be arrays of equal length, but rows is length {1} while " + \
-                          "cols is length {2}."
-                    raise RuntimeError(msg.format(self.pathname, len(rows), len(cols)))
+                    raise RuntimeError("{}: d({})/d({}): declare_partials has been called "
+                                       "with rows and cols, which should be arrays of equal length,"
+                                       " but rows is length {} while cols is length "
+                                       "{}.".format(self.msginfo, of, wrt, len(rows), len(cols)))
 
                 # Check for repeated rows/cols indices.
                 idxset = set(zip(rows, cols))
                 if len(rows) - len(idxset) > 0:
                     dups = [n for n, val in iteritems(Counter(zip(rows, cols))) if val > 1]
-                    raise RuntimeError("%s: declare_partials has been called with rows and cols "
-                                       "that specify the following duplicate subjacobian entries: "
-                                       "%s." % (self.pathname, sorted(dups)))
+                    raise RuntimeError("{}: d({})/d({}): declare_partials has been called "
+                                       "with rows and cols that specify the following duplicate "
+                                       "subjacobian entries: {}.".format(self.msginfo, of, wrt,
+                                                                         sorted(dups)))
 
         if method_func is not None:
             # we're doing approximations
@@ -901,7 +960,8 @@ class Component(System):
 
             # If rows/cols is specified
             if rows is not None or cols is not None:
-                raise ValueError('Sparse FD specification not supported yet.')
+                raise ValueError("{}: d({})/d({}): Sparse FD specification not supported "
+                                 "yet.".format(self.msginfo, of, wrt))
         else:
             default_opts = ()
 
@@ -909,17 +969,20 @@ class Component(System):
             if 'step' in default_opts:
                 meta['step'] = step
             else:
-                raise RuntimeError("'step' is not a valid option for '%s'" % method)
+                raise RuntimeError("{}: d({})/d({}): 'step' is not a valid option for "
+                                   "'{}'".format(self.msginfo, of, wrt, method))
         if form:
             if 'form' in default_opts:
                 meta['form'] = form
             else:
-                raise RuntimeError("'form' is not a valid option for '%s'" % method)
+                raise RuntimeError("{}: d({})/d({}): 'form' is not a valid option for "
+                                   "'{}'".format(self.msginfo, of, wrt, method))
         if step_calc:
             if 'step_calc' in default_opts:
                 meta['step_calc'] = step_calc
             else:
-                raise RuntimeError("'step_calc' is not a valid option for '%s'" % method)
+                raise RuntimeError("{}: d({})/d({}): 'step_calc' is not a valid option "
+                                   "for '{}'".format(self.msginfo, of, wrt, method))
 
         return meta
 
@@ -933,6 +996,7 @@ class Component(System):
                          tol=_DEFAULT_COLORING_META['tol'],
                          orders=_DEFAULT_COLORING_META['orders'],
                          perturb_size=_DEFAULT_COLORING_META['perturb_size'],
+                         min_improve_pct=_DEFAULT_COLORING_META['min_improve_pct'],
                          show_summary=_DEFAULT_COLORING_META['show_summary'],
                          show_sparsity=_DEFAULT_COLORING_META['show_sparsity']):
         """
@@ -963,6 +1027,9 @@ class Component(System):
             Number of orders above and below the tolerance to check during the tolerance sweep.
         perturb_size : float
             Size of input/output perturbation during generation of sparsity.
+        min_improve_pct : float
+            If coloring does not improve (decrease) the number of solves more than the given
+            percentage, coloring will not be used.
         show_summary : bool
             If True, display summary information after generating coloring.
         show_sparsity : bool
@@ -970,7 +1037,7 @@ class Component(System):
         """
         super(Component, self).declare_coloring(wrt, method, form, step, per_instance,
                                                 num_full_jacs,
-                                                tol, orders, perturb_size,
+                                                tol, orders, perturb_size, min_improve_pct,
                                                 show_summary, show_sparsity)
         # create approx partials for all matches
         meta = self.declare_partials('*', wrt, method=method, step=step, form=form)
@@ -1004,27 +1071,27 @@ class Component(System):
         """
         supported_methods = ('fd', 'cs')
         if method not in supported_methods:
-            msg = "Method '{}' is not supported, method must be one of {}"
-            raise ValueError(msg.format(method, supported_methods))
+            msg = "{}: Method '{}' is not supported, method must be one of {}"
+            raise ValueError(msg.format(self.msginfo, method, supported_methods))
 
         if step and not isinstance(step, (int, float)):
-            msg = "The value of 'step' must be numeric, but '{}' was specified."
-            raise ValueError(msg.format(step))
+            msg = "{}: The value of 'step' must be numeric, but '{}' was specified."
+            raise ValueError(msg.format(self.msginfo, step))
 
         supported_step_calc = ('abs', 'rel')
         if step_calc and step_calc not in supported_step_calc:
-            msg = "The value of 'step_calc' must be one of {}, but '{}' was specified."
-            raise ValueError(msg.format(supported_step_calc, step_calc))
+            msg = "{}: The value of 'step_calc' must be one of {}, but '{}' was specified."
+            raise ValueError(msg.format(self.msginfo, supported_step_calc, step_calc))
 
         if not isinstance(wrt, (string_types, list, tuple)):
-            msg = "The value of 'wrt' must be a string or list of strings, but a type " \
+            msg = "{}: The value of 'wrt' must be a string or list of strings, but a type " \
                   "of '{}' was provided."
-            raise ValueError(msg.format(type(wrt).__name__))
+            raise ValueError(msg.format(self.msginfo, type(wrt).__name__))
 
         if not isinstance(directional, bool):
-            msg = "The value of 'directional' must be True or False, but a type " \
+            msg = "{}: The value of 'directional' must be True or False, but a type " \
                   "of '{}' was provided."
-            raise ValueError(msg.format(type(directional).__name__))
+            raise ValueError(msg.format(self.msginfo, type(directional).__name__))
 
         wrt_list = [wrt] if isinstance(wrt, string_types) else wrt
         self._declared_partial_checks.append((wrt_list, method, form, step, step_calc,
@@ -1072,13 +1139,8 @@ class Component(System):
                                        'directional': directional}
 
         if invalid_wrt:
-            if len(invalid_wrt) == 1:
-                msg = "Invalid 'wrt' variable specified for check_partial options on Component " \
-                      "'{}': '{}'.".format(self.pathname, invalid_wrt[0])
-            else:
-                msg = "Invalid 'wrt' variables specified for check_partial options on Component " \
-                      "'{}': {}.".format(self.pathname, invalid_wrt)
-            raise ValueError(msg)
+            msg = "{}: Invalid 'wrt' variables specified for check_partial options: {}."
+            raise ValueError(msg.format(self.msginfo, invalid_wrt))
 
         return opts
 
@@ -1111,8 +1173,9 @@ class Component(System):
                 cols = np.array(cols, dtype=INT_DTYPE, copy=False)
 
                 if rows.shape != cols.shape:
-                    raise ValueError('rows and cols must have the same shape,'
-                                     ' rows: {}, cols: {}'.format(rows.shape, cols.shape))
+                    raise ValueError('{}: d({})/d({}): rows and cols must have the same shape,'
+                                     ' rows: {}, cols: {}'.format(self.msginfo, of, wrt,
+                                                                  rows.shape, cols.shape))
 
                 if is_scalar:
                     val = np.full(rows.size, val, dtype=float)
@@ -1125,19 +1188,20 @@ class Component(System):
                     val = val.astype(safe_dtype, copy=False)
 
                     if rows.shape != val.shape:
-                        raise ValueError('If rows and cols are specified, val must be a scalar or '
-                                         'have the same shape, val: {}, '
-                                         'rows/cols: {}'.format(val.shape, rows.shape))
+                        raise ValueError('{}: d({})/d({}): If rows and cols are specified, val '
+                                         'must be a scalar or have the same shape, val: {}, '
+                                         'rows/cols: {}'.format(self.msginfo, of, wrt,
+                                                                val.shape, rows.shape))
                 else:
                     val = np.zeros_like(rows, dtype=float)
 
                 if rows.size > 0:
                     if rows.min() < 0:
                         msg = '{}: d({})/d({}): row indices must be non-negative'
-                        raise ValueError(msg.format(self.pathname, of, wrt))
+                        raise ValueError(msg.format(self.msginfo, of, wrt))
                     if cols.min() < 0:
                         msg = '{}: d({})/d({}): col indices must be non-negative'
-                        raise ValueError(msg.format(self.pathname, of, wrt))
+                        raise ValueError(msg.format(self.msginfo, of, wrt))
                     rows_max = rows.max()
                     cols_max = cols.max()
                 else:
@@ -1161,9 +1225,11 @@ class Component(System):
             of_pattern, of_matches = of_bundle
             wrt_pattern, wrt_matches = wrt_bundle
             if not of_matches:
-                raise ValueError('No matches were found for of="{}"'.format(of_pattern))
+                raise ValueError('{}: No matches were found for of="{}"'.format(self.msginfo,
+                                                                                of_pattern))
             if not wrt_matches:
-                raise ValueError('No matches were found for wrt="{}"'.format(wrt_pattern))
+                raise ValueError('{}: No matches were found for wrt="{}"'.format(self.msginfo,
+                                                                                 wrt_pattern))
 
             for rel_key in product(of_matches, wrt_matches):
                 abs_key = rel_key2abs_key(self, rel_key)
@@ -1198,7 +1264,7 @@ class Component(System):
                 if rows_max >= shape[0] or cols_max >= shape[1]:
                     of, wrt = rel_key
                     msg = '{}: d({})/d({}): Expected {}x{} but declared at least {}x{}'
-                    raise ValueError(msg.format(self.pathname, of, wrt, shape[0], shape[1],
+                    raise ValueError(msg.format(self.msginfo, of, wrt, shape[0], shape[1],
                                                 rows_max + 1, cols_max + 1))
 
                 self._check_partials_meta(abs_key, meta['value'],
@@ -1262,7 +1328,7 @@ class Component(System):
             if val_out > out_size or val_in > in_size:
                 of, wrt = abs_key2rel_key(self, abs_key)
                 msg = '{}: d({})/d({}): Expected {}x{} but val is {}x{}'
-                raise ValueError(msg.format(self.pathname, of, wrt, out_size, in_size,
+                raise ValueError(msg.format(self.msginfo, of, wrt, out_size, in_size,
                                             val_out, val_in))
 
     def _set_approx_partials_meta(self):
@@ -1273,7 +1339,7 @@ class Component(System):
         subjacs = self._subjacs_info
         for key in self._approx_subjac_keys_iter():
             meta = subjacs[key]
-            self._approx_schemes[meta['method']].add_approximation(key, meta)
+            self._approx_schemes[meta['method']].add_approximation(key, self, meta)
 
     def _guess_nonlinear(self):
         """
@@ -1295,10 +1361,9 @@ class Component(System):
         if self._first_call_to_linearize:
             self._first_call_to_linearize = False  # only do this once
             if coloring_mod._use_partial_sparsity:
-                is_dynamic = self._coloring_info['coloring'] is coloring_mod._DYN_COLORING
                 coloring = self._get_coloring()
                 if coloring is not None:
-                    if not is_dynamic:
+                    if not self._coloring_info['dynamic']:
                         coloring._check_config_partial(self)
                     self._update_subjac_sparsity(coloring.get_subjac_sparsity())
 
