@@ -968,7 +968,7 @@ class TestProblemCheckPartials(unittest.TestCase):
             comp.set_check_partial_options(wrt=np.array([1.0]))
 
         self.assertEqual(str(cm.exception),
-                         "The value of 'wrt' must be a string or list of strings, but a "
+                         "ParaboloidTricky (comp): The value of 'wrt' must be a string or list of strings, but a "
                          "type of 'ndarray' was provided.")
 
         # check invalid method
@@ -976,7 +976,7 @@ class TestProblemCheckPartials(unittest.TestCase):
             comp.set_check_partial_options(wrt=['*'], method='foo')
 
         self.assertEqual(str(cm.exception),
-                         "Method 'foo' is not supported, method must be one of ('fd', 'cs')")
+                         "ParaboloidTricky (comp): Method 'foo' is not supported, method must be one of ('fd', 'cs')")
 
         # check invalid form
         comp._declared_partial_checks = []
@@ -998,14 +998,14 @@ class TestProblemCheckPartials(unittest.TestCase):
             comp.set_check_partial_options(wrt=['*'], step='foo')
 
         self.assertEqual(str(cm.exception),
-                         "The value of 'step' must be numeric, but 'foo' was specified.")
+                         "ParaboloidTricky (comp): The value of 'step' must be numeric, but 'foo' was specified.")
 
         # check invalid step_calc
         with self.assertRaises(ValueError) as cm:
             comp.set_check_partial_options(wrt=['*'], step_calc='foo')
 
         self.assertEqual(str(cm.exception),
-                         "The value of 'step_calc' must be one of ('abs', 'rel'), "
+                         "ParaboloidTricky (comp): The value of 'step_calc' must be one of ('abs', 'rel'), "
                          "but 'foo' was specified.")
 
         # check invalid wrt
@@ -1015,8 +1015,8 @@ class TestProblemCheckPartials(unittest.TestCase):
         with self.assertRaises(ValueError) as cm:
             prob.check_partials()
 
-        self.assertEqual(str(cm.exception), "Invalid 'wrt' variable specified "
-                         "for check_partial options on Component 'comp': 'z'.")
+        self.assertEqual(str(cm.exception), "ParaboloidTricky (comp): Invalid 'wrt' variables specified "
+                         "for check_partial options: ['z'].")
 
         # check multiple invalid wrt
         comp._declared_partial_checks = []
@@ -1025,8 +1025,8 @@ class TestProblemCheckPartials(unittest.TestCase):
         with self.assertRaises(ValueError) as cm:
             prob.check_partials()
 
-        self.assertEqual(str(cm.exception), "Invalid 'wrt' variables specified "
-                         "for check_partial options on Component 'comp': ['a', 'b', 'c'].")
+        self.assertEqual(str(cm.exception), "ParaboloidTricky (comp): Invalid 'wrt' variables specified "
+                         "for check_partial options: ['a', 'b', 'c'].")
 
     def test_compact_print_formatting(self):
         class MyCompShortVarNames(om.ExplicitComponent):
@@ -1814,6 +1814,30 @@ class TestCheckPartialsFeature(unittest.TestCase):
 
         data = prob.check_partials()
 
+    def test_set_method_and_step_bug(self):
+        # If a model-builder set his a component to fd, and the global method is cs with a specified
+        # step size, that size is probably unusable, and can lead to false error in the check.
+
+        prob = om.Problem()
+
+        prob.model.add_subsystem('p1', om.IndepVarComp('x', 3.0))
+        prob.model.add_subsystem('p2', om.IndepVarComp('y', 5.0))
+        comp = prob.model.add_subsystem('comp', Paraboloid())
+
+        prob.model.connect('p1.x', 'comp.x')
+        prob.model.connect('p2.y', 'comp.y')
+
+        prob.set_solver_print(level=0)
+
+        comp.set_check_partial_options(wrt='*', method='fd')
+
+        prob.setup(force_alloc_complex=True)
+        prob.run_model()
+
+        J = prob.check_partials(compact_print=True, method='cs', step=1e-40, out_stream=None)
+
+        assert_check_partials(J, atol=1e-5, rtol=1e-5)
+
 
 class TestProblemCheckTotals(unittest.TestCase):
 
@@ -2203,6 +2227,12 @@ class TestProblemCheckTotals(unittest.TestCase):
         assert_rel_error(self, J[('sub.time.time', 'sub.time_extents.t_duration')]['J_fwd'][0], 17.0, 1e-5)
         assert_rel_error(self, J[('sub.time.time', 'sub.time_extents.t_duration')]['J_fd'][0], 17.0, 1e-5)
 
+        # Make sure check_totals cleans up after itself by running it a second time.
+        J = p.check_totals(out_stream=None)
+
+        assert_rel_error(self, J[('sub.time.time', 'sub.time_extents.t_duration')]['J_fwd'][0], 17.0, 1e-5)
+        assert_rel_error(self, J[('sub.time.time', 'sub.time_extents.t_duration')]['J_fd'][0], 17.0, 1e-5)
+
     def test_vector_scaled_derivs(self):
 
         prob = om.Problem()
@@ -2353,6 +2383,40 @@ class TestProblemCheckTotals(unittest.TestCase):
                 "setup on the problem, e.g. 'problem.setup(force_alloc_complex=True)'"
         self.assertEqual(str(cm.exception), msg)
 
+    def test_fd_zero_check(self):
+
+        class BadComp(om.ExplicitComponent):
+
+            def setup(self):
+                self.add_input('x', 3.0)
+                self.add_output('y', 3.0)
+
+                self.declare_partials('y', 'x')
+
+            def compute(self, inputs, outputs):
+                pass
+
+            def compute_partials(self, inputs, partials):
+                partials['y', 'x'] = 3.0 * inputs['x'] + 5
+
+        prob = om.Problem()
+        model = prob.model
+
+        model.add_subsystem('p', om.IndepVarComp('x', 3.0))
+        model.add_subsystem('comp', BadComp())
+        model.connect('p.x', 'comp.x')
+
+        model.add_design_var('p.x')
+        model.add_objective('comp.y')
+
+        prob.setup()
+        prob.run_model()
+
+        # This test verifies fix of a TypeError (division by None)
+        J = prob.check_totals(out_stream=None)
+        assert_rel_error(self, J['comp.y', 'p.x']['J_fwd'], [[14.0]], 1e-6)
+        assert_rel_error(self, J['comp.y', 'p.x']['J_fd'], [[0.0]], 1e-6)
+
 
 @unittest.skipUnless(MPI and PETScVector, "only run under MPI with PETSc.")
 class TestProblemCheckTotalsMPI(unittest.TestCase):
