@@ -87,7 +87,7 @@ class DynPartialsComp(om.ExplicitComponent):
 
 
 def run_opt(driver_class, mode, assemble_type=None, color_info=None, sparsity=None, derivs=True,
-            recorder=None, has_lin_constraint=True, vectorize=True, partial_coloring=False,
+            recorder=None, has_lin_constraint=True, has_diag_partials=True, partial_coloring=False,
             **options):
 
     p = om.Problem(model=CounterGroup())
@@ -109,25 +109,25 @@ def run_opt(driver_class, mode, assemble_type=None, color_info=None, sparsity=No
     if partial_coloring:
         arctan_yox = DynPartialsComp(SIZE)
     else:
-        arctan_yox = om.ExecComp('g=arctan(y/x)', vectorize=vectorize,
+        arctan_yox = om.ExecComp('g=arctan(y/x)', has_diag_partials=has_diag_partials,
                                  g=np.ones(SIZE), x=np.ones(SIZE), y=np.ones(SIZE))
 
     p.model.add_subsystem('arctan_yox', arctan_yox)
 
     p.model.add_subsystem('circle', om.ExecComp('area=pi*r**2'))
 
-    p.model.add_subsystem('r_con', om.ExecComp('g=x**2 + y**2 - r', vectorize=vectorize,
+    p.model.add_subsystem('r_con', om.ExecComp('g=x**2 + y**2 - r', has_diag_partials=has_diag_partials,
                                                g=np.ones(SIZE), x=np.ones(SIZE), y=np.ones(SIZE)))
 
     thetas = np.linspace(0, np.pi/4, SIZE)
-    p.model.add_subsystem('theta_con', om.ExecComp('g = x - theta', vectorize=vectorize,
+    p.model.add_subsystem('theta_con', om.ExecComp('g = x - theta', has_diag_partials=has_diag_partials,
                                                    g=np.ones(SIZE), x=np.ones(SIZE),
                                                    theta=thetas))
-    p.model.add_subsystem('delta_theta_con', om.ExecComp('g = even - odd', vectorize=vectorize,
+    p.model.add_subsystem('delta_theta_con', om.ExecComp('g = even - odd', has_diag_partials=has_diag_partials,
                                                          g=np.ones(SIZE//2), even=np.ones(SIZE//2),
                                                          odd=np.ones(SIZE//2)))
 
-    p.model.add_subsystem('l_conx', om.ExecComp('g=x-1', vectorize=vectorize, g=np.ones(SIZE), x=np.ones(SIZE)))
+    p.model.add_subsystem('l_conx', om.ExecComp('g=x-1', has_diag_partials=has_diag_partials, g=np.ones(SIZE), x=np.ones(SIZE)))
 
     IND = np.arange(SIZE, dtype=int)
     ODD_IND = IND[1::2]  # all odd indices
@@ -146,7 +146,7 @@ def run_opt(driver_class, mode, assemble_type=None, color_info=None, sparsity=No
         del options['method']
 
     if 'dynamic_total_coloring' in options:
-        p.driver.declare_coloring()
+        p.driver.declare_coloring(tol=1e-15)
         del options['dynamic_total_coloring']
 
     p.driver.options.update(options)
@@ -277,7 +277,7 @@ class SimulColoringPyoptSparseTestCase(unittest.TestCase):
         # first, run w/o coloring
         p = run_opt(pyOptSparseDriver, 'fwd', optimizer='SNOPT', print_results=False, has_lin_constraint=False, method='cs')
         p_color = run_opt(pyOptSparseDriver, 'fwd', optimizer='SNOPT', has_lin_constraint=False,
-                          vectorize=True, print_results=False,
+                          has_diag_partials=True, print_results=False,
                           dynamic_total_coloring=True, method='cs')
 
         assert_almost_equal(p['circle.area'], np.pi, decimal=7)
@@ -296,7 +296,7 @@ class SimulColoringPyoptSparseTestCase(unittest.TestCase):
         # first, run w/o coloring
         p = run_opt(pyOptSparseDriver, 'fwd', optimizer='SNOPT', print_results=False, has_lin_constraint=False, method='cs')
         p_color = run_opt(pyOptSparseDriver, 'fwd', optimizer='SNOPT', has_lin_constraint=False,
-                          vectorize=True, print_results=False,
+                          has_diag_partials=True, print_results=False,
                           dynamic_total_coloring=True, method='fd')
 
         assert_almost_equal(p['circle.area'], np.pi, decimal=7)
@@ -467,23 +467,23 @@ class SimulColoringScipyTestCase(unittest.TestCase):
                                           -0.86236787, -0.97500023,  0.47739414,  0.51174103,  0.10052582]))
         indeps.add_output('r', .7)
 
-        p.model.add_subsystem('arctan_yox', om.ExecComp('g=arctan(y/x)', vectorize=True,
+        p.model.add_subsystem('arctan_yox', om.ExecComp('g=arctan(y/x)', has_diag_partials=True,
                                                         g=np.ones(SIZE), x=np.ones(SIZE), y=np.ones(SIZE)))
 
         p.model.add_subsystem('circle', om.ExecComp('area=pi*r**2'))
 
-        p.model.add_subsystem('r_con', om.ExecComp('g=x**2 + y**2 - r', vectorize=True,
+        p.model.add_subsystem('r_con', om.ExecComp('g=x**2 + y**2 - r', has_diag_partials=True,
                                                    g=np.ones(SIZE), x=np.ones(SIZE), y=np.ones(SIZE)))
 
         thetas = np.linspace(0, np.pi/4, SIZE)
-        p.model.add_subsystem('theta_con', om.ExecComp('g = x - theta', vectorize=True,
+        p.model.add_subsystem('theta_con', om.ExecComp('g = x - theta', has_diag_partials=True,
                                                        g=np.ones(SIZE), x=np.ones(SIZE),
                                                        theta=thetas))
-        p.model.add_subsystem('delta_theta_con', om.ExecComp('g = even - odd', vectorize=True,
+        p.model.add_subsystem('delta_theta_con', om.ExecComp('g = even - odd', has_diag_partials=True,
                                                              g=np.ones(SIZE//2), even=np.ones(SIZE//2),
                                                              odd=np.ones(SIZE//2)))
 
-        p.model.add_subsystem('l_conx', om.ExecComp('g=x-1', vectorize=True, g=np.ones(SIZE), x=np.ones(SIZE)))
+        p.model.add_subsystem('l_conx', om.ExecComp('g=x-1', has_diag_partials=True, g=np.ones(SIZE), x=np.ones(SIZE)))
 
         IND = np.arange(SIZE, dtype=int)
         ODD_IND = IND[1::2]  # all odd indices
@@ -574,18 +574,18 @@ class SimulColoringScipyTestCase(unittest.TestCase):
 
         p.model.add_subsystem('circle', om.ExecComp('area=pi*r**2'))
 
-        p.model.add_subsystem('r_con', om.ExecComp('g=x**2 + y**2 - r', vectorize=True,
+        p.model.add_subsystem('r_con', om.ExecComp('g=x**2 + y**2 - r', has_diag_partials=True,
                                                    g=np.ones(SIZE), x=np.ones(SIZE), y=np.ones(SIZE)))
 
         thetas = np.linspace(0, np.pi/4, SIZE)
-        p.model.add_subsystem('theta_con', om.ExecComp('g = x - theta', vectorize=True,
+        p.model.add_subsystem('theta_con', om.ExecComp('g = x - theta', has_diag_partials=True,
                                                        g=np.ones(SIZE), x=np.ones(SIZE),
                                                        theta=thetas))
-        p.model.add_subsystem('delta_theta_con', om.ExecComp('g = even - odd', vectorize=True,
+        p.model.add_subsystem('delta_theta_con', om.ExecComp('g = even - odd', has_diag_partials=True,
                                                              g=np.ones(SIZE//2), even=np.ones(SIZE//2),
                                                              odd=np.ones(SIZE//2)))
 
-        p.model.add_subsystem('l_conx', om.ExecComp('g=x-1', vectorize=True, g=np.ones(SIZE), x=np.ones(SIZE)))
+        p.model.add_subsystem('l_conx', om.ExecComp('g=x-1', has_diag_partials=True, g=np.ones(SIZE), x=np.ones(SIZE)))
 
         IND = np.arange(SIZE, dtype=int)
         ODD_IND = IND[1::2]  # all odd indices
@@ -673,7 +673,7 @@ class SimulColoringRevScipyTestCase(unittest.TestCase):
             sys.stdout = save_out
 
         self.assertTrue('Jacobian shape: (50, 50)  (100.00% nonzero)' in summary)
-        self.assertTrue('FWD solves: 0   REV solves: 50' in summary)
+        self.assertTrue('FWD solves: 50   REV solves: 0' in summary)
         self.assertTrue('Total colors vs. total size: 50 vs 50  (0.0% improvement)' in summary)
         self.assertFalse('Time to compute sparsity:' in summary)
         self.assertTrue('Time to compute coloring:' in summary)
@@ -687,7 +687,7 @@ class SimulColoringRevScipyTestCase(unittest.TestCase):
         dense_J = np.ones((50, 50), dtype=bool)
         coloring = _compute_coloring(dense_J, 'auto')
         rep = repr(coloring)
-        self.assertEqual(rep.replace('L', ''), 'Coloring (direction: rev, ncolors: 50, shape: (50, 50)')
+        self.assertEqual(rep.replace('L', ''), 'Coloring (direction: fwd, ncolors: 50, shape: (50, 50)')
 
     def test_bad_mode(self):
         p_color_rev = run_opt(om.ScipyOptimizeDriver, 'rev', optimizer='SLSQP', disp=False, dynamic_total_coloring=True)
@@ -942,6 +942,194 @@ class MatMultMultipointTestCase(unittest.TestCase):
             print(str(err))
 
 
+class DumbComp(om.ExplicitComponent):
+    def __init__(self, inputs, outputs, isizes, osizes, **kwargs):
+        super(DumbComp, self).__init__(**kwargs)
+        self._inames = inputs[:]
+        self._onames = outputs[:]
+        self._isizes = isizes[:]
+        self._osizes = osizes[:]
+
+    def setup(self):
+        for name, size in zip(self._inames, self._isizes):
+            self.add_input(name, val=np.zeros(size))
+
+        for name, size in zip(self._onames, self._osizes):
+            self.add_output(name, val=np.zeros(size))
+
+        self.add_output('obj', val=0.0)
+
+        self.declare_partials('*', '*', method='cs')
+
+    def compute(self, inputs, outputs):
+        mult = 1.0
+        for iname, oname in zip(self._inames, self._onames):
+            outputs[oname] = inputs[iname] * mult
+
+        outputs['obj'] = outputs[self._onames[0]][0]
+
+
+@use_tempdirs
+class SimulColoringConfigCheckTestCase(unittest.TestCase):
+    def _build_model(self, ofnames, wrtnames, sizes, color, fixed):
+        """
+        Build a model consisting of an IndepVarComp and an ExecComp with customizable vars and sizes.
+        """
+        assert len(ofnames) == len(wrtnames), 'Must have same number of OF and WRT names'
+        assert len(ofnames) == len(sizes), 'names and sizes must have same length'
+
+        p = om.Problem()
+        model = p.model
+        p.driver = om.ScipyOptimizeDriver()
+        p.driver.options['optimizer'] = 'SLSQP'
+        p.driver.options['disp'] = False
+
+        if color == 'total':
+            p.driver.declare_coloring()
+            if fixed:
+                p.driver.use_fixed_coloring()
+
+        indeps = model.add_subsystem('indeps', om.IndepVarComp())
+        for name, sz in zip(wrtnames, sizes):
+            indeps.add_output(name, val=np.ones(sz))
+            model.add_design_var('indeps.' + name)
+
+        for name in ofnames:
+            model.add_constraint('comp.' + name, lower=0.0)
+
+        inames = [n + '_in' for n in ofnames]
+        comp = model.add_subsystem('comp', DumbComp(inames, ofnames, sizes, sizes))
+        model.add_objective('comp.obj')
+
+        if color == 'partial':
+            comp.declare_coloring()
+            if fixed:
+                comp.use_fixed_coloring()
+
+        for ofname, wrtname in zip(ofnames, wrtnames):
+            model.connect('indeps.' + wrtname, 'comp.' + ofname + '_in')
+
+        p.setup()
+        p.final_setup()
+
+        return p
+
+    def test_good_total(self):
+        p = self._build_model(ofnames=['w', 'x', 'y'], wrtnames=['a', 'b', 'c'],
+                              sizes=[3, 4, 5], color='total', fixed=False)
+        p.run_driver()
+
+        p = self._build_model(ofnames=['w', 'x', 'y'], wrtnames=['a', 'b', 'c'],
+                              sizes=[3, 4, 5], color='total', fixed=True)
+        p.run_driver()
+
+    def test_good_partial(self):
+        p = self._build_model(ofnames=['w', 'x', 'y'], wrtnames=['a', 'b', 'c'],
+                              sizes=[3, 4, 5], color='partial', fixed=False)
+        p.run_driver()
+
+        p = self._build_model(ofnames=['w', 'x', 'y'], wrtnames=['a', 'b', 'c'],
+                              sizes=[3, 4, 5], color='partial', fixed=True)
+        p.run_driver()
+
+    def test_added_name_total(self):
+        p = self._build_model(ofnames=['w', 'x', 'y'], wrtnames=['a', 'b', 'c'],
+                              sizes=[3, 4, 5], color='total', fixed=False)
+        p.run_driver()
+
+        with self.assertRaises(RuntimeError) as ctx:
+            p = self._build_model(ofnames=['w', 'x', 'y', 'z'], wrtnames=['a', 'b', 'c', 'd'],
+                                sizes=[3, 4, 5, 6], color='total', fixed=True)
+
+        self.assertEqual(str(ctx.exception),
+                         "ScipyOptimizeDriver: Current coloring configuration does not match the configuration of the current model.\n   The following row vars were added: ['comp.z'].\n   The following column vars were added: ['indeps.d'].\nMake sure you don't have different problems that have the same coloring directory. Set the coloring directory by setting the value of problem.options['coloring_dir'].")
+
+    def test_added_name_partial(self):
+        p = self._build_model(ofnames=['w', 'x', 'y'], wrtnames=['a', 'b', 'c'],
+                              sizes=[3, 4, 5], color='partial', fixed=False)
+        p.run_driver()
+
+        print('++++++++++++')
+        p = self._build_model(ofnames=['w', 'x', 'y', 'z'], wrtnames=['a', 'b', 'c', 'd'],
+                                sizes=[3, 4, 5, 6], color='partial', fixed=True)
+
+        with self.assertRaises(RuntimeError) as ctx:
+            p.run_driver()
+
+        self.assertEqual(str(ctx.exception), "DumbComp (comp): Current coloring configuration does not match the configuration of the current model.\n   The following row vars were added: ['z'].\n   The following column vars were added: ['z_in'].\nMake sure you don't have different problems that have the same coloring directory. Set the coloring directory by setting the value of problem.options['coloring_dir'].")
+
+    def test_removed_name_total(self):
+        p = self._build_model(ofnames=['w', 'x', 'y'], wrtnames=['a', 'b', 'c'],
+                              sizes=[3, 4, 5], color='total', fixed=False)
+        p.run_driver()
+
+
+        with self.assertRaises(RuntimeError) as ctx:
+            p = self._build_model(ofnames=['w', 'y'], wrtnames=['a', 'c'],
+                                  sizes=[3, 5], color='total', fixed=True)
+        self.assertEqual(str(ctx.exception), "ScipyOptimizeDriver: Current coloring configuration does not match the configuration of the current model.\n   The following row vars were removed: ['comp.x'].\n   The following column vars were removed: ['indeps.b'].\nMake sure you don't have different problems that have the same coloring directory. Set the coloring directory by setting the value of problem.options['coloring_dir'].")
+
+    def test_removed_name_partial(self):
+        p = self._build_model(ofnames=['w', 'x', 'y'], wrtnames=['a', 'b', 'c'],
+                              sizes=[3, 4, 5], color='partial', fixed=False)
+        p.run_driver()
+
+        p = self._build_model(ofnames=['w', 'y'], wrtnames=['a', 'c'],
+                                sizes=[3, 5], color='partial', fixed=True)
+
+        with self.assertRaises(RuntimeError) as ctx:
+            p.run_driver()
+
+        self.assertEqual(str(ctx.exception),
+                         "DumbComp (comp): Current coloring configuration does not match the configuration of the current model.\n   The following row vars were removed: ['x'].\n   The following column vars were removed: ['x_in'].\nMake sure you don't have different problems that have the same coloring directory. Set the coloring directory by setting the value of problem.options['coloring_dir'].")
+
+    def test_reordered_name_total(self):
+        p = self._build_model(ofnames=['w', 'x', 'y'], wrtnames=['a', 'b', 'c'],
+                              sizes=[3, 4, 5], color='total', fixed=False)
+        p.run_driver()
+
+        with self.assertRaises(RuntimeError) as ctx:
+            p = self._build_model(ofnames=['w', 'y', 'x'], wrtnames=['a', 'c', 'b'],
+                                  sizes=[3, 5, 4], color='total', fixed=True)
+        self.assertEqual(str(ctx.exception), "ScipyOptimizeDriver: Current coloring configuration does not match the configuration of the current model.\n   The row vars have changed order.\n   The column vars have changed order.\nMake sure you don't have different problems that have the same coloring directory. Set the coloring directory by setting the value of problem.options['coloring_dir'].")
+
+    def test_reordered_name_partial(self):
+        p = self._build_model(ofnames=['x', 'y', 'z'], wrtnames=['a', 'b', 'c'],
+                              sizes=[3, 4, 5], color='partial', fixed=False)
+        p.run_driver()
+
+        p = self._build_model(ofnames=['x', 'z', 'y'], wrtnames=['a', 'c', 'b'],
+                              sizes=[3, 4, 5], color='partial', fixed=True)
+
+        with self.assertRaises(RuntimeError) as ctx:
+            p.run_driver()
+
+        self.assertEqual(str(ctx.exception), "DumbComp (comp): Current coloring configuration does not match the configuration of the current model.\n   The row vars have changed order.\n   The column vars have changed order.\nMake sure you don't have different problems that have the same coloring directory. Set the coloring directory by setting the value of problem.options['coloring_dir'].")
+
+    def test_size_change_total(self):
+        p = self._build_model(ofnames=['w', 'x', 'y'], wrtnames=['a', 'b', 'c'],
+                              sizes=[3, 4, 5], color='total', fixed=False)
+        p.run_driver()
+
+        with self.assertRaises(RuntimeError) as ctx:
+            p = self._build_model(ofnames=['w', 'x', 'y'], wrtnames=['a', 'b', 'c'],
+                                  sizes=[3, 7, 5], color='total', fixed=True)
+        self.assertEqual(str(ctx.exception), "ScipyOptimizeDriver: Current coloring configuration does not match the configuration of the current model.\n   The following variables have changed sizes: ['comp.x', 'indeps.b'].\nMake sure you don't have different problems that have the same coloring directory. Set the coloring directory by setting the value of problem.options['coloring_dir'].")
+
+    def test_size_change_partial(self):
+        p = self._build_model(ofnames=['x', 'y', 'z'], wrtnames=['a', 'b', 'c'],
+                              sizes=[3, 4, 5], color='partial', fixed=False)
+        p.run_driver()
+
+        p = self._build_model(ofnames=['x', 'y', 'z'], wrtnames=['a', 'b', 'c'],
+                              sizes=[3, 9, 5], color='partial', fixed=True)
+
+        with self.assertRaises(RuntimeError) as ctx:
+            p.run_driver()
+
+        self.assertEqual(str(ctx.exception), "DumbComp (comp): Current coloring configuration does not match the configuration of the current model.\n   The following variables have changed sizes: ['y', 'y_in'].\nMake sure you don't have different problems that have the same coloring directory. Set the coloring directory by setting the value of problem.options['coloring_dir'].")
+
+
 if __name__ == '__main__':
     unittest.main()
 
