@@ -9,13 +9,13 @@ from six import assertRaisesRegex, StringIO, assertRegex
 import numpy as np
 
 import openmdao.api as om
-from openmdao.core.group import get_relevant_vars
 from openmdao.core.driver import Driver
-from openmdao.devtools.problem_viewer.problem_viewer import _get_viewer_data
+from openmdao.visualization.n2_viewer.n2_viewer import _get_viewer_data
 from openmdao.test_suite.components.paraboloid import Paraboloid
 from openmdao.test_suite.components.sellar import StateConnection, \
      SellarDis1withDerivatives, SellarDis2withDerivatives
 from openmdao.utils.assert_utils import assert_rel_error
+from openmdao.utils.general_utils import remove_whitespace
 
 
 class ModCompEx(om.ExplicitComponent):
@@ -26,8 +26,8 @@ class ModCompEx(om.ExplicitComponent):
     def setup(self):
         self.add_input('a', val=10.)
         self.add_output('b', val=0.)
-        self.add_discrete_input('x', val=10)
-        self.add_discrete_output('y', val=0)
+        self.add_discrete_input('x', val=10, tags='tagx')
+        self.add_discrete_output('y', val=0, tags='tagy')
 
     def compute(self, inputs, outputs, discrete_inputs, discrete_outputs):
         outputs['b'] = inputs['a']*2.
@@ -40,8 +40,8 @@ class ModCompIm(om.ImplicitComponent):
         self.modval = modval
 
     def setup(self):
-        self.add_discrete_input('x', val=10)
-        self.add_discrete_output('y', val=0)
+        self.add_discrete_input('x', val=10, tags='tagx')
+        self.add_discrete_output('y', val=0, tags='tagy')
 
     def apply_nonlinear(self, inputs, outputs, residuals, discrete_inputs, discrete_outputs):
         discrete_outputs['y'] = discrete_inputs['x'] % self.modval
@@ -294,6 +294,128 @@ class DiscreteTestCase(unittest.TestCase):
         self.assertEqual(text.count('  impl'), 1)
         self.assertEqual(text.count('    y'), 2)      # both implicit & explicit
 
+    def test_list_inputs_outputs_promoted(self):
+        model = om.Group()
+
+        indep = om.IndepVarComp()
+        indep.add_discrete_output('x', 11)
+
+        model.add_subsystem('indep', indep, promotes_outputs=['x'])
+
+        model.add_subsystem('expl', ModCompEx(3), promotes_inputs=['x'])
+        model.add_subsystem('impl', ModCompIm(3), promotes_inputs=['x'])
+
+        prob = om.Problem(model)
+        prob.setup()
+        prob.run_model()
+
+        #
+        # list inputs
+        #
+        stream = StringIO()
+
+        model.list_inputs(hierarchical=False, prom_name=True, out_stream=stream)
+
+        text = stream.getvalue().split('\n')
+
+        expected = [
+            "3 Input(s) in 'model'",
+            "---------------------",
+            "",
+            "varname  value  prom_name",
+            "-------  -----  ---------",
+            "expl.a   [10.]  expl.a",
+            "expl.x   11     x",
+            "impl.x   11     x",
+        ]
+
+        for i, line in enumerate(expected):
+            if line and not line.startswith('-'):
+                self.assertEqual(remove_whitespace(text[i]), remove_whitespace(line))
+
+        #
+        # list outputs
+        #
+        stream = StringIO()
+
+        model.list_outputs(prom_name=True, out_stream=stream)
+
+        text = stream.getvalue().split('\n')
+
+        expected = [
+            "3 Explicit Output(s) in 'model'",
+            "-------------------------------",
+            "",
+            "varname  value  prom_name",
+            "-------  -----  ---------",
+            "top",
+            "  indep",
+            "    x    11     x",
+            "  expl",
+            "    b    [20.]  expl.b",
+            "    y    2      expl.y",
+            "",
+            "",
+            "1 Implicit Output(s) in 'model'",
+            "-------------------------------",
+            "",
+            "varname  value  prom_name",
+            "-------  -----  ---------",
+            "top",
+            "  impl",
+            "    y    2      impl.y",
+        ]
+
+        for i, line in enumerate(expected):
+            if line and not line.startswith('-'):
+                self.assertEqual(remove_whitespace(text[i]), remove_whitespace(line))
+
+    def test_list_inputs_outputs_with_tags(self):
+        prob = om.Problem()
+        model = prob.model
+
+        indep = model.add_subsystem('indep', om.IndepVarComp())
+        indep.add_discrete_output('x', 11)
+
+        model.add_subsystem('expl', ModCompEx(3))
+        model.add_subsystem('impl', ModCompIm(3))
+
+        model.connect('indep.x', ['expl.x', 'impl.x'])
+
+        prob.setup()
+        prob.run_model()
+
+        # list inputs, no tags
+        inputs = prob.model.list_inputs(values=False, out_stream=None)
+        self.assertEqual(sorted(inputs), [
+            ('expl.a', {}),
+            ('expl.x', {}),
+            ('impl.x', {}),
+        ])
+
+        # list inputs, with tags
+        inputs = prob.model.list_inputs(values=False, out_stream=None, tags='tagx')
+        self.assertEqual(sorted(inputs), [
+            ('expl.x', {}),
+            ('impl.x', {}),
+        ])
+
+        # list outputs, no tags
+        outputs = prob.model.list_outputs(values=False, out_stream=None)
+        self.assertEqual(sorted(outputs), [
+            ('expl.b', {}),
+            ('expl.y', {}),
+            ('impl.y', {}),
+            ('indep.x', {}),
+        ])
+
+        # list outputs, with tags
+        outputs = prob.model.list_outputs(values=False, out_stream=None, tags='tagy')
+        self.assertEqual(sorted(outputs), [
+            ('expl.y', {}),
+            ('impl.y', {}),
+        ])
+
     def test_float_to_discrete_error(self):
         prob = om.Problem()
         model = prob.model
@@ -307,7 +429,7 @@ class DiscreteTestCase(unittest.TestCase):
         with self.assertRaises(Exception) as ctx:
             prob.setup()
         self.assertEqual(str(ctx.exception),
-                         "Can't connect discrete output 'indep.x' to continuous input 'comp.x'.")
+                         "Group (<model>): Can't connect continuous output 'indep.x' to discrete input 'comp.x'.")
 
     def test_discrete_to_float_error(self):
         prob = om.Problem()
@@ -322,7 +444,7 @@ class DiscreteTestCase(unittest.TestCase):
         with self.assertRaises(Exception) as ctx:
             prob.setup()
         self.assertEqual(str(ctx.exception),
-                         "Can't connect discrete output 'indep.x' to continuous input 'comp.x'.")
+                         "Group (<model>): Can't connect discrete output 'indep.x' to continuous input 'comp.x'.")
 
     def test_discrete_mismatch_error(self):
         prob = om.Problem()
@@ -337,7 +459,7 @@ class DiscreteTestCase(unittest.TestCase):
         with self.assertRaises(Exception) as ctx:
             prob.setup()
         self.assertEqual(str(ctx.exception),
-                         "Type 'str' of output 'indep.x' is incompatible with type 'int' of input 'comp.x'.")
+                         "Group (<model>): Type 'str' of output 'indep.x' is incompatible with type 'int' of input 'comp.x'.")
 
     def test_driver_discrete_enforce_int(self):
         # Drivers require discrete vars to be int or ndarrays of int.
@@ -354,17 +476,17 @@ class DiscreteTestCase(unittest.TestCase):
         prob.driver = DiscreteDriver()
         prob.setup()
 
+        msg = "Only integer scalars or ndarrays are supported as values " + \
+              "for discrete variables when used as a design variable. %s " + \
+              "was specified."
+
         # Insert a non integer
         prob['indep.x'] = 3.7
 
         with self.assertRaises(Exception) as ctx:
             prob.run_driver()
 
-        msg = "Only integer scalars or ndarrays are supported as values for " + \
-              "discrete variables when used as a design variable. "
-        msg += "A value of type 'float' was specified."
-
-        self.assertEqual(str(ctx.exception), msg)
+        self.assertEqual(str(ctx.exception), msg % "A value of type 'float'")
 
         # Insert a float ndarray
         prob['indep.x'] = np.array([3.0])
@@ -372,11 +494,7 @@ class DiscreteTestCase(unittest.TestCase):
         with self.assertRaises(Exception) as ctx:
             prob.run_driver()
 
-        msg = "Only integer scalars or ndarrays are supported as values for " + \
-              "discrete variables when used as a design variable. "
-        msg += "An array of type 'float64' was specified."
-
-        self.assertEqual(str(ctx.exception), msg)
+        self.assertEqual(str(ctx.exception), msg % "An array of type 'float64'")
 
         # Make sure these work.
 
@@ -516,7 +634,7 @@ class SolverDiscreteTestCase(unittest.TestCase):
             prob.run_model()
 
         self.assertEqual(str(ctx.exception),
-                         "System '' has a NewtonSolver solver and contains discrete outputs ['discrete_g.C1.y'].")
+                         "Group (<model>) has a NewtonSolver solver and contains discrete outputs ['discrete_g.C1.y'].")
 
     def test_discrete_err_broyden(self):
         prob = self._setup_model(om.BroydenSolver)
@@ -525,7 +643,7 @@ class SolverDiscreteTestCase(unittest.TestCase):
             prob.run_model()
 
         self.assertEqual(str(ctx.exception),
-                         "System '' has a BroydenSolver solver and contains discrete outputs ['discrete_g.C1.y'].")
+                         "Group (<model>) has a BroydenSolver solver and contains discrete outputs ['discrete_g.C1.y'].")
 
 
 class DiscretePromTestCase(unittest.TestCase):
@@ -609,7 +727,7 @@ class DiscretePromTestCase(unittest.TestCase):
             else:
                 yield name
 
-        # add a test to see if discrete vars show up in view_model
+        # add a test to see if discrete vars show up in n2
         data = _get_viewer_data(prob)
         findvars = [
             'indep.x',
@@ -672,6 +790,56 @@ class DiscreteFeatureTestCase(unittest.TestCase):
         # minimum value
         assert_rel_error(self, prob['SolidityComp.blade_solidity'], 0.02984155, 1e-4)
 
+    def test_feature_discrete_implicit(self):
+        import openmdao.api as om
+
+        class ImpWithInitial(om.ImplicitComponent):
+            """
+            An implicit component to solve the quadratic equation: x^2 - 4x + 3
+            (solutions at x=1 and x=3)
+            """
+            def setup(self):
+                self.add_input('a', val=1.)
+                self.add_input('b', val=-4.)
+                self.add_discrete_input('c', val=3)
+                self.add_output('x', val=5.)
+
+                self.declare_partials(of='*', wrt='*')
+
+            def apply_nonlinear(self, inputs, outputs, residuals, discrete_inputs, discrete_outputs):
+                a = inputs['a']
+                b = inputs['b']
+                c = discrete_inputs['c']
+                x = outputs['x']
+                residuals['x'] = a * x ** 2 + b * x + c
+
+            def linearize(self, inputs, outputs, partials, discrete_inputs, discrete_outputs):
+                a = inputs['a']
+                b = inputs['b']
+                x = outputs['x']
+
+                partials['x', 'a'] = x ** 2
+                partials['x', 'b'] = x
+                partials['x', 'x'] = 2 * a * x + b
+
+            def guess_nonlinear(self, inputs, outputs, resids, discrete_inputs, discrete_outputs):
+                # Default initial state of zero for x takes us to x=1 solution.
+                # Here we set it to a value that will take us to the x=3 solution.
+                outputs['x'] = 5
+
+        prob = om.Problem()
+        model = prob.model
+
+        model.add_subsystem('comp', ImpWithInitial())
+
+        model.nonlinear_solver = om.NewtonSolver()
+        model.linear_solver = om.ScipyKrylov()
+
+        prob.setup()
+        prob.run_model()
+
+        assert_rel_error(self, prob['comp.x'], 3., 1e-4)
+
 
 if __name__ == "__main__":
     unittest.main()
