@@ -3,11 +3,18 @@
 from __future__ import division, print_function
 
 import unittest
+import itertools
+
 import numpy as np
 
 import openmdao.api as om
 from openmdao.utils.mpi import MPI
 
+try:
+    from parameterized import parameterized
+except ImportError:
+    from openmdao.utils.assert_utils import SkipParameterized as parameterized
+
 try:
     from openmdao.vectors.petsc_vector import PETScVector
 except ImportError:
@@ -21,18 +28,42 @@ from openmdao.utils.logger_utils import TestLogger
 from openmdao.error_checking.check_config import _default_checks
 
 
+class Noisy(ConvergeDiverge):
+    def check_config(self, logger):
+        msg = 'Only want to see this on rank 0'
+        logger.error(msg)
+        logger.warning(msg)
+        logger.info(msg)
+
+
+def _test_func_name(func, num, param):
+    args = []
+    for p in param.args:
+        try:
+            arg = p.__name__
+        except:
+            arg = str(p)
+        args.append(arg)
+    return func.__name__ + '_' + '_'.join(args)
+
 
 @unittest.skipUnless(MPI and PETScVector, "MPI and PETSc are required.")
 class TestParallelGroups(unittest.TestCase):
 
     N_PROCS = 2
 
-    def test_fan_out_grouped(self):
+    @parameterized.expand(itertools.product([om.LinearRunOnce, om.DirectSolver],
+                                            [om.NonlinearBlockGS, om.NonLinearRunOnce]),
+                          name_func=_test_func_name)
+    def test_fan_out_grouped(self, solver, nlsolver):
         prob = om.Problem(FanOutGrouped())
 
         of=['c2.y', "c3.y"]
         wrt=['iv.x']
 
+        prob.model.linear_solver = solver()
+        prob.model.nonlinear_solver = nlsolver()
+
         prob.setup(check=False, mode='fwd')
         prob.set_solver_print(level=0)
         prob.run_model()
@@ -56,15 +87,21 @@ class TestParallelGroups(unittest.TestCase):
         assert_rel_error(self, prob['c2.y'], -6.0, 1e-6)
         assert_rel_error(self, prob['c3.y'], 15.0, 1e-6)
 
-    def test_fan_in_grouped(self):
+    @parameterized.expand(itertools.product([om.LinearRunOnce, om.DirectSolver],
+                                            [om.NonlinearBlockGS, om.NonLinearRunOnce]),
+                          name_func=_test_func_name)
+    def test_fan_in_grouped(self, solver, nlsolver):
 
         prob = om.Problem()
         prob.model = FanInGrouped2()
+
+        prob.model.linear_solver = solver()
+        prob.model.nonlinear_solver = nlsolver()
+
         prob.setup(check=False, mode='fwd')
         prob.set_solver_print(level=0)
         prob.run_model()
 
-
         indep_list = ['p1.x', 'p2.x']
         unknown_list = ['c3.y']
 
@@ -74,6 +111,11 @@ class TestParallelGroups(unittest.TestCase):
         assert_rel_error(self, J['c3.y', 'p1.x'][0][0], -6.0, 1e-6)
         assert_rel_error(self, J['c3.y', 'p2.x'][0][0], 35.0, 1e-6)
 
+        # do this a second time to test caching of dist rows/cols
+        J = prob.compute_totals(of=unknown_list, wrt=indep_list)
+        assert_rel_error(self, J['c3.y', 'p1.x'][0][0], -6.0, 1e-6)
+        assert_rel_error(self, J['c3.y', 'p2.x'][0][0], 35.0, 1e-6)
+
         assert_rel_error(self, prob['c3.y'], 29.0, 1e-6)
 
         prob.setup(check=False, mode='rev')
@@ -85,6 +127,11 @@ class TestParallelGroups(unittest.TestCase):
         assert_rel_error(self, J['c3.y', 'p1.x'][0][0], -6.0, 1e-6)
         assert_rel_error(self, J['c3.y', 'p2.x'][0][0], 35.0, 1e-6)
 
+        # do this a second time to test caching of dist rows/cols
+        J = prob.compute_totals(of=unknown_list, wrt=indep_list)
+        assert_rel_error(self, J['c3.y', 'p1.x'][0][0], -6.0, 1e-6)
+        assert_rel_error(self, J['c3.y', 'p2.x'][0][0], 35.0, 1e-6)
+
         assert_rel_error(self, prob['c3.y'], 29.0, 1e-6)
 
     def test_fan_in_grouped_feature(self):
@@ -114,10 +161,17 @@ class TestParallelGroups(unittest.TestCase):
 
         assert_rel_error(self, prob['c3.y'], 29.0, 1e-6)
 
-    def test_diamond(self):
+    @parameterized.expand(itertools.product([om.LinearRunOnce, om.DirectSolver],
+                                            [om.NonlinearBlockGS, om.NonLinearRunOnce]),
+                          name_func=_test_func_name)
+    def test_diamond(self, solver, nlsolver):
 
         prob = om.Problem()
         prob.model = Diamond()
+
+        prob.model.linear_solver = solver()
+        prob.model.nonlinear_solver = nlsolver()
+
         prob.setup(check=False, mode='fwd')
         prob.set_solver_print(level=0)
         prob.run_model()
@@ -142,10 +196,17 @@ class TestParallelGroups(unittest.TestCase):
         assert_rel_error(self, J['c4.y1', 'iv.x'][0][0], 25, 1e-6)
         assert_rel_error(self, J['c4.y2', 'iv.x'][0][0], -40.5, 1e-6)
 
-    def test_converge_diverge(self):
+    @parameterized.expand(itertools.product([om.LinearRunOnce, om.DirectSolver],
+                                            [om.NonlinearBlockGS, om.NonLinearRunOnce]),
+                          name_func=_test_func_name)
+    def test_converge_diverge(self, solver, nlsolver):
 
         prob = om.Problem()
         prob.model = ConvergeDiverge()
+
+        prob.model.linear_solver = solver()
+        prob.model.nonlinear_solver = nlsolver()
+
         prob.setup(check=False, mode='fwd')
         prob.set_solver_print(level=0)
         prob.run_model()
@@ -236,13 +297,7 @@ class TestParallelGroups(unittest.TestCase):
         assert_rel_error(self, prob['c2.y'], -6.0, 1e-6)
         assert_rel_error(self, prob['c3.y'], 15.0, 1e-6)
 
-    def test_setup_messages(self):
-
-        class Noisy(ConvergeDiverge):
-            def check_config(self, logger):
-                logger.error(msg)
-                logger.warning(msg)
-                logger.info(msg)
+    def test_setup_messages_bad_vec_type(self):
 
         prob = om.Problem(Noisy())
 
@@ -257,11 +312,13 @@ class TestParallelGroups(unittest.TestCase):
         else:
             prob.setup(check=False, mode='fwd')
 
+    def test_setup_messages_only_on_proc0(self):
+        prob = om.Problem(Noisy())
+
         # check that we get setup messages only on proc 0
         msg = 'Only want to see this on rank 0'
         testlogger = TestLogger()
-        prob.setup(check=True, mode='fwd',
-                   logger=testlogger)
+        prob.setup(check=True, mode='fwd', logger=testlogger)
         prob.final_setup()
 
         if prob.comm.rank > 0:
