@@ -2,18 +2,24 @@
 
 import sys
 import unittest
+import itertools
 
-from six import assertRaisesRegex, StringIO, assertRegex, iteritems
+from six import assertRaisesRegex, StringIO, assertRegex
 
 import numpy as np
 
 import openmdao.api as om
-from openmdao.core.group import get_relevant_vars
+from openmdao.core.system import get_relevant_vars
 from openmdao.core.driver import Driver
 from openmdao.utils.assert_utils import assert_rel_error, assert_warning
 from openmdao.test_suite.components.paraboloid import Paraboloid
 from openmdao.test_suite.components.sellar import SellarDerivatives
 
+try:
+    from parameterized import parameterized
+except ImportError:
+    from openmdao.utils.assert_utils import SkipParameterized as parameterized
+
 
 class SellarOneComp(om.ImplicitComponent):
 
@@ -470,6 +476,51 @@ class TestProblem(unittest.TestCase):
 
         assert_rel_error(self, derivs['calc.y', 'des_vars.x'], [[2.0]], 1e-6)
 
+    @parameterized.expand(itertools.product(['fwd', 'rev']))
+    def test_compute_jacvec_product(self, mode):
+
+        prob = om.Problem()
+        prob.model = SellarDerivatives()
+        prob.model.nonlinear_solver = om.NonlinearBlockGS()
+
+        prob.setup(mode=mode)
+        prob.run_model()
+
+        of = ['obj', 'con1']
+        wrt = ['x', 'z']
+
+        if mode == 'fwd':
+            seed_names = wrt
+            result_names = of
+            rvec = prob.model._vectors['output']['linear']
+            lvec = prob.model._vectors['residual']['linear']
+        else:
+            seed_names = of
+            result_names = wrt
+            rvec = prob.model._vectors['residual']['linear']
+            lvec = prob.model._vectors['output']['linear']
+
+        J = prob.compute_totals(of, wrt, return_format='array')
+
+        seed = []
+        for name in seed_names:
+            seed.append(np.random.random(rvec[name].size))
+
+        resdict = prob.compute_jacvec_product(of, wrt, mode, seed)
+        result = []
+        for name in result_names:
+            result.append(resdict[name].flat)
+        result = np.hstack(result)
+
+        testvec = np.hstack(seed)
+
+        if mode == 'fwd':
+            checkvec = J.dot(testvec)
+        else:
+            checkvec = J.T.dot(testvec)
+
+        np.testing.assert_allclose(checkvec, result)
+
     def test_feature_set_indeps(self):
         import openmdao.api as om
         from openmdao.test_suite.components.paraboloid import Paraboloid
@@ -510,7 +561,6 @@ class TestProblem(unittest.TestCase):
         prob.run_model()
         assert_rel_error(self, prob['f_xy'], 22.0, 1e-6)
 
-        # skip the setup error checking
         prob.setup()
         prob['x'] = 4
         prob['y'] = 8.
@@ -1009,6 +1059,27 @@ class TestProblem(unittest.TestCase):
         assert_rel_error(self, prob.get_val('comp.x'), np.array([1.0, 5.0]), 1e-6)
         assert_rel_error(self, prob.get_val('comp.x', 'm', indices=1), 5.0e-2, 1e-6)
 
+    def test_feature_get_set_array_with_slicer(self):
+        import numpy as np
+        import openmdao.api as om
+
+        prob = om.Problem()
+        prob.model.add_subsystem('comp', om.ExecComp('y=x+1.',
+                                                     x={'value': np.array([[1., 2.], [3., 4.]]), },
+                                                     y={'shape': (2, 2), }))
+
+        prob.setup()
+        prob.run_model()
+
+        assert_rel_error(self, prob.get_val('comp.x', indices=om.slicer[:, 0]), [1., 3.], 1e-6)
+        assert_rel_error(self, prob.get_val('comp.x', indices=om.slicer[0, 1]), 2., 1e-6)
+        assert_rel_error(self, prob.get_val('comp.x', indices=om.slicer[1, -1]), 4., 1e-6)
+
+        prob.set_val('comp.x', [5., 6.], indices=om.slicer[:,0])
+        assert_rel_error(self, prob.get_val('comp.x', indices=om.slicer[:, 0]), [5., 6.], 1e-6)
+        prob.run_model()
+        assert_rel_error(self, prob.get_val('comp.y', indices=om.slicer[:, 0]), [6., 7.], 1e-6)
+
     def test_feature_set_get_array(self):
         import numpy as np
 
@@ -1661,11 +1732,11 @@ class TestProblem(unittest.TestCase):
             sys.stdout = stdout
         output = strout.getvalue().split('\n')
         assertRegex(self, output[6], r'^\s+value:')
-        assertRegex(self, output[7], r'^\s+\[[0-9. e+-]+\]')
+        assertRegex(self, output[7], r'^\s+array+\(+\[[0-9., e+-]+\]+\)')
         assertRegex(self, output[9], r'^\s+lower:')
-        assertRegex(self, output[10], r'^\s+\[[0-9. e+-]+\]')
+        assertRegex(self, output[10], r'^\s+array+\(+\[[0-9., e+-]+\]+\)')
         assertRegex(self, output[12], r'^\s+upper:')
-        assertRegex(self, output[13], r'^\s+\[[0-9. e+-]+\]')
+        assertRegex(self, output[13], r'^\s+array+\(+\[[0-9., e+-]+\]+\)')
 
     def test_feature_list_problem_vars(self):
         import numpy as np
@@ -1700,8 +1771,8 @@ class TestProblem(unittest.TestCase):
                                           'indices', 'adder', 'scaler',
                                           'parallel_deriv_color',
                                           'vectorize_derivs',
-                                          'cache_linear_solution'],
-                               )
+                                          'cache_linear_solution'])
+
 
 class NestedProblemTestCase(unittest.TestCase):
 
