@@ -19,7 +19,7 @@ class DenseMatrix(COOMatrix):
     Dense global matrix.
     """
 
-    def _build(self, num_rows, num_cols, in_ranges, out_ranges):
+    def _build(self, num_rows, num_cols, system=None):
         """
         Allocate the matrix.
 
@@ -29,15 +29,13 @@ class DenseMatrix(COOMatrix):
             number of rows in the matrix.
         num_cols : int
             number of cols in the matrix.
-        in_ranges : dict
-            Maps input var name to column range.
-        out_ranges : dict
-            Maps output var name to row range.
+        system : <System>
+            owning system.
         """
-        super(DenseMatrix, self)._build(num_rows, num_cols, in_ranges, out_ranges)
+        super(DenseMatrix, self)._build(num_rows, num_cols)
         self._coo = self._matrix
 
-    def _prod(self, in_vec, mode, ranges, mask=None):
+    def _prod(self, in_vec, mode, mask=None):
         """
         Perform a matrix vector product.
 
@@ -47,8 +45,6 @@ class DenseMatrix(COOMatrix):
             incoming vector to multiply.
         mode : str
             'fwd' or 'rev'.
-        ranges : (int, int, int, int)
-            Min row, max row, min col, max col for the current system.
         mask : ndarray of type bool, or None
             Array used to mask out part of the input vector.
 
@@ -61,21 +57,15 @@ class DenseMatrix(COOMatrix):
         # group that owns the AssembledJacobian, we need to use only
         # the part of the matrix that is relevant to the lower level
         # system.
-        if ranges is None:
-            mat = self._matrix
-        else:
-            rstart, rend, cstart, cend = ranges
-            mat = self._matrix[rstart:rend, cstart:cend]
+        mat = self._matrix
 
         if mode == 'fwd':
             if mask is None:
                 return mat.dot(in_vec)
             else:
-                inputs_masked = np.ma.array(in_vec, mask=mask)
-
                 # Use the special dot product function from masking module so that we
                 # ignore masked parts.
-                return np.ma.dot(mat, inputs_masked)
+                return np.ma.dot(mat, np.ma.array(in_vec, mask=mask))
         else:  # rev
             if mask is None:
                 return mat.T.dot(in_vec)
