@@ -47,4 +47,5 @@ class LinearRunOnce(LinearBlockGS):
 
         # this solver does not iterate
         self.options.undeclare("maxiter")
-        self.options.undeclare("err_on_maxiter")
+        self.options.undeclare("err_on_maxiter")    # Deprecated option.
+        self.options.undeclare("err_on_non_converge")
