@@ -7,10 +7,7 @@ import unittest
 
 import numpy as np
 
-from openmdao.api import Group, IndepVarComp, Problem, ExecComp, NonlinearBlockGS, BoundsEnforceLS
-from openmdao.solvers.linear.linear_block_gs import LinearBlockGS
-from openmdao.solvers.linear.scipy_iter_solver import ScipyKrylov, ScipyIterativeSolver
-from openmdao.solvers.nonlinear.newton import NewtonSolver
+import openmdao.api as om
 from openmdao.solvers.linear.tests.linear_test_base import LinearSolverTests
 from openmdao.test_suite.components.expl_comp_simple import TestExplCompSimpleDense
 from openmdao.test_suite.components.misc_components import Comp4LinearCacheTest
@@ -22,7 +19,7 @@ from openmdao.utils.assert_utils import assert_rel_error, assert_warning
 # use this to fake out the TestImplicitGroup so it'll use the solver we want.
 def krylov_factory(solver):
     def f(junk=None):
-        return ScipyKrylov(solver=solver)
+        return om.ScipyKrylov(solver=solver)
     return f
 
 
@@ -34,7 +31,7 @@ class TestScipyKrylov(LinearSolverTests.LinearSolverTestCase):
     def test_options(self):
         """Verify that the SciPy solver specific options are declared."""
 
-        group = Group()
+        group = om.Group()
         group.linear_solver = self.linear_solver_class()
 
         self.assertEqual(group.linear_solver.options['solver'], self.linear_solver_name)
@@ -47,10 +44,10 @@ class TestScipyKrylov(LinearSolverTests.LinearSolverTestCase):
         msg = "ScipyIterativeSolver is deprecated.  Use ScipyKrylov instead."
 
         with assert_warning(DeprecationWarning, msg):
-            group = TestImplicitGroup(lnSolverClass=lambda : ScipyIterativeSolver(solver=self.linear_solver_name))
+            group = TestImplicitGroup(lnSolverClass=lambda : om.ScipyIterativeSolver(solver=self.linear_solver_name))
 
-        p = Problem(group)
-        p.setup(check=False)
+        p = om.Problem(group)
+        p.setup()
         p.set_solver_print(level=0)
 
         # Conclude setup but don't run model.
@@ -78,8 +75,8 @@ class TestScipyKrylov(LinearSolverTests.LinearSolverTestCase):
         group = TestImplicitGroup(lnSolverClass=self.linear_solver_class)
         group.linear_solver.options['maxiter'] = 2
 
-        p = Problem(group)
-        p.setup(check=False)
+        p = om.Problem(group)
+        p.setup()
         p.set_solver_print(level=0)
 
         # Conclude setup but don't run model.
@@ -104,16 +101,16 @@ class TestScipyKrylov(LinearSolverTests.LinearSolverTestCase):
     def test_solve_on_subsystem(self):
         """solve an implicit system with GMRES attached to a subsystem"""
 
-        p = Problem()
-        model = p.model = Group()
-        dv = model.add_subsystem('des_vars', IndepVarComp())
+        p = om.Problem()
+        model = p.model
+        dv = model.add_subsystem('des_vars', om.IndepVarComp())
         # just need a dummy variable so the sizes don't match between root and g1
         dv.add_output('dummy', val=1.0, shape=10)
 
         grp = TestImplicitGroup(lnSolverClass=self.linear_solver_class)
         g1 = model.add_subsystem('g1', grp)
 
-        p.setup(check=False)
+        p.setup()
 
         p.set_solver_print(level=0)
 
@@ -150,7 +147,7 @@ class TestScipyKrylov(LinearSolverTests.LinearSolverTestCase):
 
         # check deprecation on setter & getter
         with assert_warning(DeprecationWarning, msg):
-            group.linear_solver.preconditioner = LinearBlockGS()
+            group.linear_solver.preconditioner = om.LinearBlockGS()
 
         with assert_warning(DeprecationWarning, msg):
             group.linear_solver.preconditioner
@@ -162,14 +159,14 @@ class TestScipyKrylov(LinearSolverTests.LinearSolverTestCase):
 
         # Forward mode
 
-        prob = Problem()
+        prob = om.Problem()
         model = prob.model
 
-        model.add_subsystem('px', IndepVarComp('x', 1.0), promotes=['x'])
+        model.add_subsystem('px', om.IndepVarComp('x', 1.0), promotes=['x'])
         model.add_subsystem('d1', Comp4LinearCacheTest(), promotes=['x', 'y'])
 
-        model.nonlinear_solver = NonlinearBlockGS()
-        model.linear_solver = ScipyKrylov()
+        model.nonlinear_solver = om.NonlinearBlockGS()
+        model.linear_solver = om.ScipyKrylov()
 
         model.add_design_var('x', cache_linear_solution=True)
         model.add_objective('y', cache_linear_solution=True)
@@ -188,14 +185,14 @@ class TestScipyKrylov(LinearSolverTests.LinearSolverTestCase):
 
         # Reverse mode
 
-        prob = Problem()
+        prob = om.Problem()
         model = prob.model
 
-        model.add_subsystem('px', IndepVarComp('x', 1.0), promotes=['x'])
+        model.add_subsystem('px', om.IndepVarComp('x', 1.0), promotes=['x'])
         model.add_subsystem('d1', Comp4LinearCacheTest(), promotes=['x', 'y'])
 
-        model.nonlinear_solver = NonlinearBlockGS()
-        model.linear_solver = ScipyKrylov()
+        model.nonlinear_solver = om.NonlinearBlockGS()
+        model.linear_solver = om.ScipyKrylov()
 
         model.add_design_var('x', cache_linear_solution=True)
         model.add_objective('y', cache_linear_solution=True)
@@ -218,18 +215,18 @@ class TestScipyKrylovFeature(unittest.TestCase):
     def test_feature_simple(self):
         """Tests feature for adding a Scipy GMRES solver and calculating the
         derivatives."""
-        from openmdao.api import Problem, Group, IndepVarComp, ScipyKrylov
+        import openmdao.api as om
         from openmdao.test_suite.components.expl_comp_simple import TestExplCompSimpleDense
 
         # Tests derivatives on a simple comp that defines compute_jacvec.
-        prob = Problem()
+        prob = om.Problem()
         model = prob.model
-        model.add_subsystem('x_param', IndepVarComp('length', 3.0),
+        model.add_subsystem('x_param', om.IndepVarComp('length', 3.0),
                             promotes=['length'])
         model.add_subsystem('mycomp', TestExplCompSimpleDense(),
                             promotes=['length', 'width', 'area'])
 
-        model.linear_solver = ScipyKrylov()
+        model.linear_solver = om.ScipyKrylov()
         prob.set_solver_print(level=0)
 
         prob.setup(check=False, mode='fwd')
@@ -245,30 +242,29 @@ class TestScipyKrylovFeature(unittest.TestCase):
     def test_specify_solver(self):
         import numpy as np
 
-        from openmdao.api import Problem, Group, IndepVarComp, ScipyKrylov, \
-             NonlinearBlockGS, ExecComp
+        import openmdao.api as om
         from openmdao.test_suite.components.sellar import SellarDis1withDerivatives, \
              SellarDis2withDerivatives
 
-        prob = Problem()
+        prob = om.Problem()
         model = prob.model
 
-        model.add_subsystem('px', IndepVarComp('x', 1.0), promotes=['x'])
-        model.add_subsystem('pz', IndepVarComp('z', np.array([5.0, 2.0])), promotes=['z'])
+        model.add_subsystem('px', om.IndepVarComp('x', 1.0), promotes=['x'])
+        model.add_subsystem('pz', om.IndepVarComp('z', np.array([5.0, 2.0])), promotes=['z'])
 
         model.add_subsystem('d1', SellarDis1withDerivatives(), promotes=['x', 'z', 'y1', 'y2'])
         model.add_subsystem('d2', SellarDis2withDerivatives(), promotes=['z', 'y1', 'y2'])
 
-        model.add_subsystem('obj_cmp', ExecComp('obj = x**2 + z[1] + y1 + exp(-y2)',
-                                                z=np.array([0.0, 0.0]), x=0.0),
+        model.add_subsystem('obj_cmp', om.ExecComp('obj = x**2 + z[1] + y1 + exp(-y2)',
+                                                   z=np.array([0.0, 0.0]), x=0.0),
                             promotes=['obj', 'x', 'z', 'y1', 'y2'])
 
-        model.add_subsystem('con_cmp1', ExecComp('con1 = 3.16 - y1'), promotes=['con1', 'y1'])
-        model.add_subsystem('con_cmp2', ExecComp('con2 = y2 - 24.0'), promotes=['con2', 'y2'])
+        model.add_subsystem('con_cmp1', om.ExecComp('con1 = 3.16 - y1'), promotes=['con1', 'y1'])
+        model.add_subsystem('con_cmp2', om.ExecComp('con2 = y2 - 24.0'), promotes=['con2', 'y2'])
 
-        model.nonlinear_solver = NonlinearBlockGS()
+        model.nonlinear_solver = om.NonlinearBlockGS()
 
-        model.linear_solver = ScipyKrylov()
+        model.linear_solver = om.ScipyKrylov()
 
         prob.setup()
         prob.run_model()
@@ -283,28 +279,28 @@ class TestScipyKrylovFeature(unittest.TestCase):
     def test_feature_maxiter(self):
         import numpy as np
 
-        from openmdao.api import Problem, Group, IndepVarComp, ScipyKrylov, NonlinearBlockGS, ExecComp
+        import openmdao.api as om
         from openmdao.test_suite.components.sellar import SellarDis1withDerivatives, SellarDis2withDerivatives
 
-        prob = Problem()
+        prob = om.Problem()
         model = prob.model
 
-        model.add_subsystem('px', IndepVarComp('x', 1.0), promotes=['x'])
-        model.add_subsystem('pz', IndepVarComp('z', np.array([5.0, 2.0])), promotes=['z'])
+        model.add_subsystem('px', om.IndepVarComp('x', 1.0), promotes=['x'])
+        model.add_subsystem('pz', om.IndepVarComp('z', np.array([5.0, 2.0])), promotes=['z'])
 
         model.add_subsystem('d1', SellarDis1withDerivatives(), promotes=['x', 'z', 'y1', 'y2'])
         model.add_subsystem('d2', SellarDis2withDerivatives(), promotes=['z', 'y1', 'y2'])
 
-        model.add_subsystem('obj_cmp', ExecComp('obj = x**2 + z[1] + y1 + exp(-y2)',
-                                                z=np.array([0.0, 0.0]), x=0.0),
+        model.add_subsystem('obj_cmp', om.ExecComp('obj = x**2 + z[1] + y1 + exp(-y2)',
+                                                   z=np.array([0.0, 0.0]), x=0.0),
                             promotes=['obj', 'x', 'z', 'y1', 'y2'])
 
-        model.add_subsystem('con_cmp1', ExecComp('con1 = 3.16 - y1'), promotes=['con1', 'y1'])
-        model.add_subsystem('con_cmp2', ExecComp('con2 = y2 - 24.0'), promotes=['con2', 'y2'])
+        model.add_subsystem('con_cmp1', om.ExecComp('con1 = 3.16 - y1'), promotes=['con1', 'y1'])
+        model.add_subsystem('con_cmp2', om.ExecComp('con2 = y2 - 24.0'), promotes=['con2', 'y2'])
 
-        model.nonlinear_solver = NonlinearBlockGS()
+        model.nonlinear_solver = om.NonlinearBlockGS()
 
-        model.linear_solver = ScipyKrylov()
+        model.linear_solver = om.ScipyKrylov()
         model.linear_solver.options['maxiter'] = 3
 
         prob.setup()
@@ -320,28 +316,28 @@ class TestScipyKrylovFeature(unittest.TestCase):
     def test_feature_atol(self):
         import numpy as np
 
-        from openmdao.api import Problem, Group, IndepVarComp, ScipyKrylov, NonlinearBlockGS, ExecComp
+        import openmdao.api as om
         from openmdao.test_suite.components.sellar import SellarDis1withDerivatives, SellarDis2withDerivatives
 
-        prob = Problem()
+        prob = om.Problem()
         model = prob.model
 
-        model.add_subsystem('px', IndepVarComp('x', 1.0), promotes=['x'])
-        model.add_subsystem('pz', IndepVarComp('z', np.array([5.0, 2.0])), promotes=['z'])
+        model.add_subsystem('px', om.IndepVarComp('x', 1.0), promotes=['x'])
+        model.add_subsystem('pz', om.IndepVarComp('z', np.array([5.0, 2.0])), promotes=['z'])
 
         model.add_subsystem('d1', SellarDis1withDerivatives(), promotes=['x', 'z', 'y1', 'y2'])
         model.add_subsystem('d2', SellarDis2withDerivatives(), promotes=['z', 'y1', 'y2'])
 
-        model.add_subsystem('obj_cmp', ExecComp('obj = x**2 + z[1] + y1 + exp(-y2)',
-                                                z=np.array([0.0, 0.0]), x=0.0),
+        model.add_subsystem('obj_cmp', om.ExecComp('obj = x**2 + z[1] + y1 + exp(-y2)',
+                                                   z=np.array([0.0, 0.0]), x=0.0),
                             promotes=['obj', 'x', 'z', 'y1', 'y2'])
 
-        model.add_subsystem('con_cmp1', ExecComp('con1 = 3.16 - y1'), promotes=['con1', 'y1'])
-        model.add_subsystem('con_cmp2', ExecComp('con2 = y2 - 24.0'), promotes=['con2', 'y2'])
+        model.add_subsystem('con_cmp1', om.ExecComp('con1 = 3.16 - y1'), promotes=['con1', 'y1'])
+        model.add_subsystem('con_cmp2', om.ExecComp('con2 = y2 - 24.0'), promotes=['con2', 'y2'])
 
-        model.nonlinear_solver = NonlinearBlockGS()
+        model.nonlinear_solver = om.NonlinearBlockGS()
 
-        model.linear_solver = ScipyKrylov()
+        model.linear_solver = om.ScipyKrylov()
         model.linear_solver.options['atol'] = 1.0e-20
 
         prob.setup()
@@ -357,35 +353,33 @@ class TestScipyKrylovFeature(unittest.TestCase):
     def test_specify_precon(self):
         import numpy as np
 
-        from openmdao.api import Problem, Group, ScipyKrylov, NewtonSolver, LinearBlockGS, \
-             DirectSolver, ExecComp, PETScKrylov
-
+        import openmdao.api as om
         from openmdao.test_suite.components.quad_implicit import QuadraticComp
 
-        prob = Problem()
+        prob = om.Problem()
         model = prob.model
 
-        sub1 = model.add_subsystem('sub1', Group())
+        sub1 = model.add_subsystem('sub1', om.Group())
         sub1.add_subsystem('q1', QuadraticComp())
-        sub1.add_subsystem('z1', ExecComp('y = -6.0 + .01 * x'))
-        sub2 = model.add_subsystem('sub2', Group())
+        sub1.add_subsystem('z1', om.ExecComp('y = -6.0 + .01 * x'))
+        sub2 = model.add_subsystem('sub2', om.Group())
         sub2.add_subsystem('q2', QuadraticComp())
-        sub2.add_subsystem('z2', ExecComp('y = -6.0 + .01 * x'))
+        sub2.add_subsystem('z2', om.ExecComp('y = -6.0 + .01 * x'))
 
         model.connect('sub1.q1.x', 'sub1.z1.x')
         model.connect('sub1.z1.y', 'sub2.q2.c')
         model.connect('sub2.q2.x', 'sub2.z2.x')
         model.connect('sub2.z2.y', 'sub1.q1.c')
 
-        model.nonlinear_solver = NewtonSolver()
-        model.linear_solver = ScipyKrylov()
+        model.nonlinear_solver = om.NewtonSolver()
+        model.linear_solver = om.ScipyKrylov()
 
         prob.setup()
 
-        model.sub1.linear_solver = DirectSolver()
-        model.sub2.linear_solver = DirectSolver()
+        model.sub1.linear_solver = om.DirectSolver()
+        model.sub2.linear_solver = om.DirectSolver()
 
-        model.linear_solver.precon = LinearBlockGS()
+        model.linear_solver.precon = om.LinearBlockGS()
 
         prob.set_solver_print(level=2)
         prob.run_model()
