@@ -40,9 +40,9 @@ class TestNonlinearRunOnceSolver(unittest.TestCase):
         # Test that using options that should not exist in class cause an error
         solver = om.NonlinearRunOnce()
 
-        msg = "\"Option '%s' cannot be set because it has not been declared.\""
+        msg = "\"NonlinearRunOnce: Option '%s' cannot be set because it has not been declared.\""
 
-        for option in ['atol', 'rtol', 'maxiter', 'err_on_maxiter']:
+        for option in ['atol', 'rtol', 'maxiter', 'err_on_non_converge']:
             with self.assertRaises(KeyError) as context:
                 solver.options[option] = 1
 
