@@ -5,10 +5,10 @@ import numpy as np
 import scipy.sparse
 import scipy.optimize
 
-from openmdao.api import ImplicitComponent
+import openmdao.api as om
 
 
-class TestImplCompSimple(ImplicitComponent):
+class TestImplCompSimple(om.ImplicitComponent):
 
     def setup(self):
         self.add_input('a', val=1.)
