@@ -2,10 +2,11 @@
 Demonstration of a model using the Paraboloid component.
 """
 from __future__ import division, print_function
-from openmdao.api import ExplicitComponent
+
+import openmdao.api as om
 
 
-class Paraboloid(ExplicitComponent):
+class Paraboloid(om.ExplicitComponent):
     """
     Evaluates the equation f(x,y) = (x-3)^2 + xy + (y+4)^2 - 3.
     """
@@ -32,12 +33,9 @@ class Paraboloid(ExplicitComponent):
 
 
 if __name__ == "__main__":
-    from openmdao.core.problem import Problem
-    from openmdao.core.group import Group
-    from openmdao.core.indepvarcomp import IndepVarComp
 
-    model = Group()
-    ivc = IndepVarComp()
+    model = om.Group()
+    ivc = om.IndepVarComp()
     ivc.add_output('x', 3.0)
     ivc.add_output('y', -4.0)
     model.add_subsystem('des_vars', ivc)
@@ -46,7 +44,7 @@ if __name__ == "__main__":
     model.connect('des_vars.x', 'parab_comp.x')
     model.connect('des_vars.y', 'parab_comp.y')
 
-    prob = Problem(model)
+    prob = om.Problem(model)
     prob.setup()
     prob.run_model()
     print(prob['parab_comp.f_xy'])
