@@ -6,7 +6,6 @@ import openmdao.api as om
 from openmdao.test_suite.test_examples.beam_optimization.components.moment_comp import MomentOfInertiaComp
 from openmdao.test_suite.test_examples.beam_optimization.components.local_stiffness_matrix_comp import LocalStiffnessMatrixComp
 from openmdao.test_suite.test_examples.beam_optimization.components.states_comp import StatesComp
-from openmdao.test_suite.test_examples.beam_optimization.components.displacements_comp import DisplacementsComp
 from openmdao.test_suite.test_examples.beam_optimization.components.compliance_comp import ComplianceComp
 from openmdao.test_suite.test_examples.beam_optimization.components.volume_comp import VolumeComp
 
@@ -44,9 +43,6 @@ class BeamGroup(om.Group):
         comp = StatesComp(num_elements=num_elements, force_vector=force_vector)
         self.add_subsystem('states_comp', comp)
 
-        comp = DisplacementsComp(num_elements=num_elements)
-        self.add_subsystem('displacements_comp', comp)
-
         comp = ComplianceComp(num_elements=num_elements, force_vector=force_vector)
         self.add_subsystem('compliance_comp', comp)
 
@@ -55,18 +51,10 @@ class BeamGroup(om.Group):
 
         self.connect('inputs_comp.h', 'I_comp.h')
         self.connect('I_comp.I', 'local_stiffness_matrix_comp.I')
-        self.connect(
-            'local_stiffness_matrix_comp.K_local',
-            'states_comp.K_local')
-        self.connect(
-            'states_comp.d',
-            'displacements_comp.d')
-        self.connect(
-            'displacements_comp.displacements',
-            'compliance_comp.displacements')
-        self.connect(
-            'inputs_comp.h',
-            'volume_comp.h')
+        self.connect('local_stiffness_matrix_comp.K_local', 'states_comp.K_local')
+        self.connect('states_comp.d', 'compliance_comp.displacements',
+                     src_indices=np.arange(2 *num_nodes))
+        self.connect('inputs_comp.h', 'volume_comp.h')
 
         self.add_design_var('inputs_comp.h', lower=1e-2, upper=10.)
         self.add_objective('compliance_comp.compliance')
