@@ -4,7 +4,7 @@ import unittest
 
 from openmdao.utils.assert_utils import assert_warning
 
-from six import PY3, assertRegex
+from six import assertRegex
 
 from openmdao.core.explicitcomponent import ExplicitComponent
 
@@ -39,7 +39,7 @@ class TestOptionsDict(unittest.TestCase):
             "Option    Default      Acceptable Values Acceptable Types      Description         ",
             "========= ============ ================= ===================== ====================",
             "comp      MyComp       N/A               ['ExplicitComponent']                     ",
-            "flag      False        N/A               ['bool']                                  ",
+            "flag      False        [True, False]     ['bool']                                  ",
             "long_desc **Required** N/A               ['str']               This description is ",
             "                                                               long and verbose, so",
             "                                                                it takes up multipl",
@@ -59,7 +59,7 @@ class TestOptionsDict(unittest.TestCase):
             "==================================================================== ",
             "comp      MyComp       N/A               ['ExplicitComponent']                      "
             "                                                                     ",
-            "flag      False        N/A               ['bool']                                   "
+            "flag      False        [True, False]     ['bool']                                   "
             "                                                                     ",
             "long_desc **Required** N/A               ['str']               This description is l"
             "ong and verbose, so it takes up multiple lines in the options table. ",
@@ -69,7 +69,6 @@ class TestOptionsDict(unittest.TestCase):
             "==================================================================== ",
         ]))
 
-
     def test_type_checking(self):
         self.dict.declare('test', types=int, desc='Test integer value')
 
@@ -79,16 +78,37 @@ class TestOptionsDict(unittest.TestCase):
         with self.assertRaises(TypeError) as context:
             self.dict['test'] = ''
 
-        class_or_type = 'class' if PY3 else 'type'
-        expected_msg = "Value ('') of option 'test' has type of (<{} 'str'>), but expected type (<{} 'int'>).".format(class_or_type, class_or_type)
+        expected_msg = "Value ('') of option 'test' has type 'str', " \
+                       "but type 'int' was expected."
         self.assertEqual(expected_msg, str(context.exception))
 
-        # make sure bools work
+        # multiple types are allowed
+        self.dict.declare('test_multi', types=(int, float), desc='Test multiple types')
+
+        self.dict['test_multi'] = 1
+        self.assertEqual(self.dict['test_multi'], 1)
+        self.assertEqual(type(self.dict['test_multi']), int)
+
+        self.dict['test_multi'] = 1.0
+        self.assertEqual(self.dict['test_multi'], 1.0)
+        self.assertEqual(type(self.dict['test_multi']), float)
+
+        with self.assertRaises(TypeError) as context:
+            self.dict['test_multi'] = ''
+
+        expected_msg = "Value ('') of option 'test_multi' has type 'str', " \
+                       "but one of types ('int', 'float') was expected."
+        self.assertEqual(expected_msg, str(context.exception))
+
+        # make sure bools work and allowed values are populated
         self.dict.declare('flag', default=False, types=bool)
         self.assertEqual(self.dict['flag'], False)
         self.dict['flag'] = True
         self.assertEqual(self.dict['flag'], True)
 
+        meta = self.dict._dict['flag']
+        self.assertEqual(meta['values'], (True, False))
+
     def test_allow_none(self):
         self.dict.declare('test', types=int, allow_none=True, desc='Test integer value')
         self.dict['test'] = None
